@@ -5,12 +5,12 @@
  * it under the terms of either:
  *
  *   The LGPL as published by the Free Software Foundation, version
- *   2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+ *   2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
  *
  * Or:
  *
  *   The Mozilla Public License Version 2.0. You may obtain a copy of
- *   the License at https://www.mozilla.org/MPL/
+ *   the License at http://www.mozilla.org/MPL/
  */
 
 #include "generator.h"
@@ -232,7 +232,7 @@ gchar *get_upper_snake_from_lower_snake(const gchar *lowerSnake)
     g_return_val_if_fail(lowerSnake != NULL && *lowerSnake != '\0', NULL);
 
     ret = g_new(gchar, BUFFER_SIZE);
-    memset(ret, 0, BUFFER_SIZE);
+    ret[0] = '\0';
 
     for (i = 0; i < (guint)strlen(lowerSnake); i++) {
         if (lowerSnake[i] == '_') {
@@ -905,18 +905,10 @@ void generate_code_from_template(FILE *in, FILE *out, Structure *structure, GHas
                     generate_source_includes(out, structure);
                 } else if (g_strcmp0(buffer, "header_declaration") == 0) {
                     generate_header_header_declaration(out, structure);
-                } else if (g_strcmp0(buffer, "body_declaration") == 0) {
-                    generate_source_body_declaration(out, structure);
                 } else if (g_hash_table_contains(table, buffer)) {
                     val = g_hash_table_lookup(table, buffer);
                     write_str(out, val);
                     val = NULL;
-
-                    if (g_strcmp0(buffer, "new_full_extraCode") == 0)
-                        write_str(out, "\n    ");
-                } else if (g_strcmp0(buffer, "new_full_extraCode") == 0) {
-                    /* For simplicity, after lookup in the 'table', to
-                       not force declaration of it in every .xml file */
                 } else if (g_strcmp0(buffer, "structure_boilerplate") == 0) {
                     if (structure->native != NULL)
                         generate_header_structure_boilerplate(out, structure, table);
@@ -1104,7 +1096,6 @@ void generate_forward_declarations_header_file(GList *structures)
     gchar *typeName;
     gchar *typeKind;
     GList *link;
-    GList *typeNamesList = NULL;
     GHashTable *typeNames;
     GHashTableIter iter_table;
     gpointer key;
@@ -1150,6 +1141,7 @@ void generate_forward_declarations_header_file(GList *structures)
         if (c == '$') {
             if ((c = fgetc(in)) != '{' && c != '^') {
                 printf("The following char is not {");
+                g_free (buffer);
                 fclose(in);
                 fclose(out);
                 return;
@@ -1164,18 +1156,13 @@ void generate_forward_declarations_header_file(GList *structures)
             if (g_strcmp0(buffer, "forward_declarations") == 0) {
                 g_hash_table_iter_init(&iter_table, typeNames);
                 while (g_hash_table_iter_next(&iter_table, &key, &value)) {
-                    typeNamesList = g_list_prepend(typeNamesList, g_strdup(key));
-                }
-                typeNamesList = g_list_sort(typeNamesList, (GCompareFunc)g_strcmp0);
-                for (link = g_list_first(typeNamesList); link != NULL; link = g_list_next(link)) {
-                    typeName = link->data;
+                    typeName = (gchar *)key;
                     write_str(out, "typedef struct _");
                     write_str(out, typeName);
                     write_str(out, " ");
                     write_str(out, typeName);
                     write_str(out, ";\n");
                 }
-                g_list_free_full(typeNamesList, g_free);
             } else if (g_strcmp0(buffer, "upperSnake") == 0) {
                 write_str(out, "I_CAL_FORWARD_DECLARATIONS");
             } else {
@@ -1272,10 +1259,6 @@ GHashTable *get_hash_table_from_structure(Structure *structure)
             (void)g_hash_table_insert(table, (gchar *)"defaultNative",
                                       g_strdup(structure->defaultNative));
         }
-        if (structure->new_full_extraCode && *structure->new_full_extraCode) {
-            (void)g_hash_table_insert(table, (gchar *)"new_full_extraCode",
-                                      g_strdup(structure->new_full_extraCode));
-        }
     }
 
     (void)g_hash_table_insert(table, (char *)"native", g_strdup(structure->native));
@@ -1457,7 +1440,6 @@ static gboolean is_enum_type(const gchar *type)
         structureKind = g_hash_table_lookup(type2kind, trueType);
         res = g_strcmp0(structureKind, "enum") == 0;
     }
-    g_free (trueType);
 
     return res;
 }
@@ -1597,29 +1579,11 @@ gchar *get_translator_for_return(Ret *ret)
     return res;
 }
 
-static gboolean annotation_contains_nullable(GList *annotations) /* gchar * */
-{
-    GList *link;
-
-    for (link = annotations; link; link = g_list_next(link)) {
-        if (g_strcmp0(link->data, "allow-none") == 0 ||
-            g_strcmp0(link->data, "nullable") == 0) {
-              break;
-        }
-    }
-
-    return link != NULL;
-}
-
 gchar *get_inline_parameter(Parameter *para)
 {
     gchar *buffer;
     gchar *ret;
     gchar *translator;
-    gboolean is_nullable;
-
-    is_nullable = !para->translator && !is_enum_type(para->type) &&
-                  annotation_contains_nullable(para->annotations);
 
     buffer = g_new(gchar, BUFFER_SIZE);
     *buffer = '\0';
@@ -1633,11 +1597,6 @@ gchar *get_inline_parameter(Parameter *para)
     }
 
     if (translator != NULL) {
-        if (is_nullable) {
-            (void)g_stpcpy(buffer + strlen(buffer), "((");
-            (void)g_stpcpy(buffer + strlen(buffer), para->name);
-            (void)g_stpcpy(buffer + strlen(buffer), ")?(");
-        }
         (void)g_stpcpy(buffer + strlen(buffer), translator);
         (void)g_stpcpy(buffer + strlen(buffer), " (");
         if (para->translator == NULL && !is_enum_type(para->type))
@@ -1651,11 +1610,31 @@ gchar *get_inline_parameter(Parameter *para)
             (void)g_stpcpy(buffer + strlen(buffer), ")");
         }
         (void)g_stpcpy(buffer + strlen(buffer), ")");
-        if (is_nullable) {
-            (void)g_stpcpy(buffer + strlen(buffer), "):NULL)");
-        }
     }
 
+    /*
+       if (translator != NULL) {
+       if (para->translatorArgus != NULL) {
+       for (iter = g_list_first (para->translatorArgus); iter != NULL; iter = g_list_next (iter)) {
+       (void)g_stpcpy (buffer + strlen (buffer), ", ");
+       (void)g_stpcpy (buffer + strlen (buffer), (gchar *)iter->data);
+       }
+       }
+
+       else if (para->translator == NULL) {
+       trueType = get_true_type (para->type);
+       if (g_hash_table_contains (type2structure, trueType)) {
+       structure = g_hash_table_lookup (type2structure, trueType);
+       if (structure->isBare == FALSE) {
+       (void)g_stpcpy (buffer + strlen (buffer), ", NULL");
+       }
+       }
+       g_free (trueType);
+       }
+       (void)g_stpcpy (buffer + strlen (buffer), ")");
+       g_free (translator);
+       }
+     */
     ret = g_new(gchar, strlen(buffer) + 1);
     (void)g_stpcpy(ret, buffer);
     g_free(buffer);
@@ -2047,6 +2026,7 @@ void generate_header_enum(FILE *out, Enumeration *enumeration)
 gchar *get_source_run_time_checkers(Method *method, const gchar *namespace)
 {
     GList *iter;
+    GList *jter;
     Parameter *parameter;
     guint i;
     gchar *buffer;
@@ -2073,16 +2053,11 @@ gchar *get_source_run_time_checkers(Method *method, const gchar *namespace)
         if (parameter && parameter->type && parameter->type[strlen(parameter->type) - 1] == '*') {
             trueType = get_true_type(parameter->type);
             for (i = 0;
-                 i < namespace_len && trueType[i] && namespace[i] == trueType[i];
+                 trueType[i] && i < namespace_len && namespace[i] == trueType[i];
                  i++);
 
             if (i == namespace_len) {
                 (void)g_stpcpy(buffer + strlen(buffer), "\t");
-                if (annotation_contains_nullable(parameter->annotations)) {
-                    (void)g_stpcpy(buffer + strlen(buffer), "if(");
-                    (void)g_stpcpy(buffer + strlen(buffer), parameter->name);
-                    (void)g_stpcpy(buffer + strlen(buffer), ")\n\t\t");
-                }
                 nameSpaceUpperSnake = get_upper_snake_from_upper_camel(namespace);
                 nameUpperSnake = get_upper_snake_from_upper_camel(trueType + i);
                 typeCheck =
@@ -2120,7 +2095,14 @@ gchar *get_source_run_time_checkers(Method *method, const gchar *namespace)
                 (void)g_stpcpy(buffer + strlen(buffer), "\n");
             }
 
-            if (i != namespace_len && !annotation_contains_nullable(parameter->annotations)) {
+            for (jter = g_list_first(parameter->annotations); jter != NULL;
+                 jter = g_list_next(jter)) {
+                if (g_strcmp0((gchar *)jter->data, "allow-none") == 0) {
+                    break;
+                }
+            }
+
+            if (jter == NULL) {
                 (void)g_stpcpy(buffer + strlen(buffer), "\t");
                 if (method->ret != NULL) {
                     (void)g_stpcpy(buffer + strlen(buffer), "g_return_val_if_fail (");
@@ -2174,12 +2156,9 @@ static gint generate_library(const gchar *apis_dir)
     gchar *buffer;
     GList *structures;
     GList *iter_list;
-    GList *filenames = NULL;
-    GList *iter_filenames;
     GDir *dir;
     GError *local_error = NULL;
     gint res = 0;
-    gint len;
 
     g_return_val_if_fail(apis_dir != NULL, 1);
     g_return_val_if_fail(g_file_test(apis_dir, G_FILE_TEST_IS_DIR), 1);
@@ -2207,13 +2186,7 @@ static gint generate_library(const gchar *apis_dir)
 
     /* Parse the all the XML files into the Structure */
     while (filename = g_dir_read_name(dir), filename) {
-        filenames = g_list_prepend(filenames, g_strdup(filename));
-    }
-    filenames = g_list_sort(filenames, (GCompareFunc)g_strcmp0);
-    for (iter_filenames = g_list_first(filenames); iter_filenames != NULL;
-        iter_filenames = g_list_next(iter_filenames)) {
-        filename = iter_filenames->data;
-        len = (gint)strlen(filename);
+        gint len = (gint)strlen(filename);
 
         if (len <= 4 || g_ascii_strncasecmp(filename + len - 4, ".xml", 4) != 0)
             continue;
@@ -2307,13 +2280,12 @@ static gint generate_library(const gchar *apis_dir)
     g_hash_table_destroy(type2structure);
     g_hash_table_destroy(defaultValues);
     g_list_free_full(structures, (GDestroyNotify)structure_free);
-    g_list_free_full(filenames, g_free);
     g_free(buffer);
 
     return res;
 }
 
-static void generate_declarations(FILE *out, Structure *structure, const gchar *position)
+void generate_header_header_declaration(FILE *out, Structure *structure)
 {
     GList *list_iter;
     Declaration *declaration;
@@ -2324,7 +2296,7 @@ static void generate_declarations(FILE *out, Structure *structure, const gchar *
          list_iter = g_list_next(list_iter)) {
         declaration = (Declaration *)list_iter->data;
 
-        if (g_strcmp0(declaration->position, position) == 0) {
+        if (g_strcmp0(declaration->position, "header") == 0) {
             write_str(out, declaration->content);
             write_str(out, "\n");
         }
@@ -2332,16 +2304,6 @@ static void generate_declarations(FILE *out, Structure *structure, const gchar *
     }
 }
 
-void generate_header_header_declaration(FILE *out, Structure *structure)
-{
-    generate_declarations(out, structure, "header");
-}
-
-void generate_source_body_declaration(FILE *out, Structure *structure)
-{
-    generate_declarations(out, structure, "body");
-}
-
 void generate_header_header_file(GList *structures)
 {
     FILE *out;
