@@ -4,7 +4,7 @@
 
  (C) COPYRIGHT 2001, Ximian, Inc.
 
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
@@ -12,16 +12,10 @@
 
  Or:
 
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
 ======================================================================*/
 
-/** @file icalarray.c
- *
- *  @brief An array of arbitrarily-sized elements which grows
- *  dynamically as elements are added.
- */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -34,9 +28,6 @@
 
 static void icalarray_expand(icalarray *array, size_t space_needed);
 
-/** @brief Constructor
- */
-
 icalarray *icalarray_new(size_t element_size, size_t increment_size)
 {
     icalarray *array;
@@ -96,9 +87,6 @@ icalarray *icalarray_copy(icalarray *originalarray)
     return array;
 }
 
-/** @brief Destructor
- */
-
 void icalarray_free(icalarray *array)
 {
     if (array->chunks) {
@@ -112,7 +100,6 @@ void icalarray_free(icalarray *array)
         array->chunks = 0;
     }
     free(array);
-    array = 0;
 }
 
 void icalarray_append(icalarray *array, const void *element)
