@@ -2,18 +2,18 @@
  FILE: icalcomponent.c
  CREATOR: eric 28 April 1999
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 ======================================================================*/
 
 #ifdef HAVE_CONFIG_H
@@ -24,13 +24,11 @@
 #include "icalerror.h"
 #include "icalmemory.h"
 #include "icalparser.h"
-#include "icalproperty_p.h"
 #include "icalrestriction.h"
 #include "icaltimezone.h"
 
 #include <assert.h>
 #include <stdlib.h>
-#include <limits.h>
 
 struct icalcomponent_impl
 {
@@ -66,6 +64,7 @@ static void icalcomponent_rename_tzids(icalcomponent *comp, icalarray *rename_ta
 static void icalcomponent_rename_tzids_callback(icalparameter *param, void *data);
 static int icalcomponent_compare_vtimezones(icalcomponent *vtimezone1, icalcomponent *vtimezone2);
 static int icalcomponent_compare_timezone_fn(const void *elem1, const void *elem2);
+static struct icaltimetype icalcomponent_get_datetime(icalcomponent *comp, icalproperty *prop);
 
 void icalcomponent_add_children(icalcomponent *impl, va_list args)
 {
@@ -108,15 +107,19 @@ static icalcomponent *icalcomponent_new_impl(icalcomponent_kind kind)
     return comp;
 }
 
+/** @brief Constructor
+ */
 icalcomponent *icalcomponent_new(icalcomponent_kind kind)
 {
     return icalcomponent_new_impl(kind);
 }
 
+/** @brief Constructor
+ */
+#pragma clang diagnostic push
+#pragma clang diagnostic ignored "-Wvarargs"
 icalcomponent *icalcomponent_vanew(icalcomponent_kind kind, ...)
 {
-    /* See https://github.com/libical/libical/issues/585. Caller must pass NULL as final argument */
-
     va_list args;
 
     icalcomponent *impl = icalcomponent_new_impl(kind);
@@ -131,12 +134,17 @@ icalcomponent *icalcomponent_vanew(icalcomponent_kind kind, ...)
 
     return impl;
 }
+#pragma clang diagnostic pop
 
+/** @brief Constructor
+ */
 icalcomponent *icalcomponent_new_from_string(const char *str)
 {
     return icalparser_parse_string(str);
 }
 
+/** @brief Constructor
+ */
 icalcomponent *icalcomponent_new_clone(icalcomponent *old)
 {
     icalcomponent *new;
@@ -165,6 +173,8 @@ icalcomponent *icalcomponent_new_clone(icalcomponent *old)
     return new;
 }
 
+/** @brief Constructor
+ */
 icalcomponent *icalcomponent_new_x(const char *x_name)
 {
     icalcomponent *comp = icalcomponent_new_impl(ICAL_X_COMPONENT);
@@ -176,6 +186,8 @@ icalcomponent *icalcomponent_new_x(const char *x_name)
     return comp;
 }
 
+/*** @brief Destructor
+ */
 void icalcomponent_free(icalcomponent *c)
 {
     icalproperty *prop;
@@ -601,6 +613,23 @@ icalcomponent *icalcomponent_get_first_real_component(icalcomponent *c)
     return 0;
 }
 
+/**     @brief Get the timespan covered by this component, in UTC
+ *
+ *      see icalcomponent_foreach_recurrence() for a better way to
+ *      extract spans from an component.
+ *
+ *      This method can be called on either a VCALENDAR or any real
+ *      component. If the VCALENDAR contains no real component, but
+ *      contains a VTIMEZONE, we return that span instead.
+ *      This might not be a desirable behavior; we keep it for now
+ *      for backward compatibility, but it might be deprecated at a
+ *      future time.
+ *
+ *      FIXME this API needs to be clarified. DTEND is defined as the
+ *      first available time after the end of this event, so the span
+ *      should actually end 1 second before DTEND.
+ */
+
 icaltime_span icalcomponent_get_span(icalcomponent *comp)
 {
     icalcomponent *inner;
@@ -656,19 +685,52 @@ or empty VCALENDAR component"); */
     }
     span.start = icaltime_as_timet_with_zone(start, icaltimezone_get_utc_timezone());
 
-    /* The end time could be specified as either a DTEND, a DURATION, or be missing */
+    /* The end time could be specified as either a DTEND or a DURATION */
     /* icalcomponent_get_dtend takes care of these cases. */
     end = icalcomponent_get_dtend(comp);
+    if (icaltime_is_null_time(end)) {
+        if (!icaltime_is_date(start)) {
+            /* If dtstart is a DATE-TIME and there is no DTEND nor DURATION
+               it takes no time */
+            span.start = 0;
+            return span;
+        } else {
+            end = start;
+        }
+    }
 
     span.end = icaltime_as_timet_with_zone(end, icaltimezone_get_utc_timezone());
     if (icaltime_is_date(start)) {
         /* Until the end of the day */
-        span.end -= 1;
+        span.end += 60 * 60 * 24 - 1;
     }
 
     return span;
 }
 
+/**
+ * Decide if this recurrance is acceptable
+ *
+ * @param comp       A valid icalcomponent.
+ * @param dtstart    The base dtstart value for this component.
+ * @param recurtime  The time to test against.
+ *
+ * @return true if the recurrence value is excluded, false otherwise.
+ *
+ * This function decides if a specific recurrence value is
+ * excluded by EXRULE or EXDATE properties.
+ *
+ * It's not the most efficient code.  You might get better performance
+ * if you assume that recurtime is always increasing for each
+ * call. Then you could:
+ *
+ *   - sort the EXDATE values
+ *   - save the state of each EXRULE iterator for the next call.
+ *
+ * In this case though you don't need to worry how you call this
+ * function.  It will always return the correct result.
+ */
+
 int icalproperty_recurrence_is_excluded(icalcomponent *comp,
                                         struct icaltimetype *dtstart,
                                         struct icaltimetype *recurtime)
@@ -687,7 +749,7 @@ int icalproperty_recurrence_is_excluded(icalcomponent *comp,
     for (exdate = icalcomponent_get_first_property(comp, ICAL_EXDATE_PROPERTY);
          exdate != NULL; exdate = icalcomponent_get_next_property(comp, ICAL_EXDATE_PROPERTY)) {
 
-        struct icaltimetype exdatetime = icalproperty_get_datetime_with_component(exdate, comp);
+        struct icaltimetype exdatetime = icalcomponent_get_datetime(comp, exdate);
 
         if ((icaltime_is_date(exdatetime) &&
              icaltime_compare_date_only(*recurtime, exdatetime) == 0) ||
@@ -730,16 +792,17 @@ int icalproperty_recurrence_is_excluded(icalcomponent *comp,
     }
     comp->property_iterator = property_iterator;
 
-    return 0; /* no matches */
+    return 0;/** no matches **/
 }
 
 /**
- * @brief Returns the busy status based on the TRANSP property.
+ * @brief Return the busy status based on the TRANSP property.
  *
  * @param comp   A valid icalcomponent.
  *
  * @return 1 if the event is a busy item, 0 if it is not.
  */
+
 static int icalcomponent_is_busy(icalcomponent *comp)
 {
     icalproperty *transp;
@@ -784,6 +847,25 @@ static int icalcomponent_is_busy(icalcomponent *comp)
     return (ret);
 }
 
+/**
+ * @brief cycle through all recurrances of an event
+ *
+ * @param comp           A valid VEVENT component
+ * @param start          Ignore timespans before this
+ * @param end            Ignore timespans after this
+ * @param callback       Function called for each timespan within the range
+ * @param callback_data  Pointer passed back to the callback function
+ *
+ * This function will call the specified callback function for once
+ * for the base value of DTSTART, and foreach recurring date/time
+ * value.
+ *
+ * It will filter out events that are specified as an EXDATE or an EXRULE.
+ *
+ * @todo We do not filter out duplicate RRULES/RDATES
+ * @todo We do not handle RDATEs with explicit periods
+ */
+
 void icalcomponent_foreach_recurrence(icalcomponent *comp,
                                       struct icaltimetype start,
                                       struct icaltimetype end,
@@ -811,9 +893,16 @@ void icalcomponent_foreach_recurrence(icalcomponent *comp,
     if (icaltime_is_null_time(dtstart))
         return;
 
-    /* The end time could be specified as either a DTEND, a DURATION or be missing */
+    /* The end time could be specified as either a DTEND or a DURATION */
     /* icalcomponent_get_dtend takes care of these cases. */
     dtend = icalcomponent_get_dtend(comp);
+    if (icaltime_is_null_time(dtend) && icaltime_is_date(dtstart)) {
+        /* No DTEND or DURATION and DTSTART is DATE - duration is 1 day */
+        struct icaldurationtype dur = icaldurationtype_null_duration();
+
+        dur.days = 1;
+        dtend = icaltime_add(dtstart, dur);
+    }
 
     /* Now set up the base span for this item, corresponding to the
        base DTSTART and DTEND */
@@ -821,12 +910,10 @@ void icalcomponent_foreach_recurrence(icalcomponent *comp,
 
     basespan.is_busy = icalcomponent_is_busy(comp);
 
-    /* Calculate the ceiling and floor values.. */
-    limit_start = icaltime_as_timet_with_zone(start,
-                                              icaltimezone_get_utc_timezone());
+  /** Calculate the ceiling and floor values.. **/
+    limit_start = icaltime_as_timet_with_zone(start, icaltimezone_get_utc_timezone());
     if (!icaltime_is_null_time(end)) {
-        limit_end = icaltime_as_timet_with_zone(end,
-                                                icaltimezone_get_utc_timezone());
+        limit_end = icaltime_as_timet_with_zone(end, icaltimezone_get_utc_timezone());
     } else {
 #if (SIZEOF_TIME_T > 4)
         limit_end = (time_t) LONG_MAX;
@@ -837,12 +924,10 @@ void icalcomponent_foreach_recurrence(icalcomponent *comp,
     limit_span.start = limit_start;
     limit_span.end = limit_end;
 
-    /* Do the callback for the DTSTART entry, ONLY if there is no RRULE.
-       Otherwise, the initial occurrence will be handled by the RRULE. */
-    rrule = icalcomponent_get_first_property(comp, ICAL_RRULE_PROPERTY);
-    if ((rrule == NULL) &&
-        !icalproperty_recurrence_is_excluded(comp, &dtstart, &dtstart)) {
-        /* call callback action */
+    /* Do the callback for the initial DTSTART entry */
+
+    if (!icalproperty_recurrence_is_excluded(comp, &dtstart, &dtstart)) {
+    /** call callback action **/
         if (icaltime_span_overlaps(&basespan, &limit_span))
             (*callback) (comp, &basespan, callback_data);
     }
@@ -851,29 +936,25 @@ void icalcomponent_foreach_recurrence(icalcomponent *comp,
     dtduration = basespan.end - basespan.start;
 
     /* Now cycle through the rrule entries */
-    for (; rrule != NULL;
-         rrule = icalcomponent_get_next_property(comp, ICAL_RRULE_PROPERTY)) {
+    for (rrule = icalcomponent_get_first_property(comp, ICAL_RRULE_PROPERTY);
+         rrule != NULL; rrule = icalcomponent_get_next_property(comp, ICAL_RRULE_PROPERTY)) {
 
         struct icalrecurrencetype recur = icalproperty_get_rrule(rrule);
         icalrecur_iterator *rrule_itr = icalrecur_iterator_new(recur, dtstart);
         struct icaltimetype rrule_time;
 
-        if (!rrule_itr) continue;
+        if (rrule_itr)
+            rrule_time = icalrecur_iterator_next(rrule_itr);
+    /** note that icalrecur_iterator_next always returns dtstart
+        the first time.. **/
 
-        if (recur.count == 0) {
-            icaltimetype mystart = start;
+        while (rrule_itr) {
+            rrule_time = icalrecur_iterator_next(rrule_itr);
 
-            /* make sure we include any recurrence that ends in timespan */
-            icaltime_adjust(&mystart, 0, 0, 0, -(int)(long)dtduration);
-            icalrecur_iterator_set_start(rrule_itr, mystart);
-        }
+            if (icaltime_is_null_time(rrule_time))
+                break;
 
-        for (rrule_time = icalrecur_iterator_next(rrule_itr);
-             !icaltime_is_null_time(rrule_time);
-             rrule_time = icalrecur_iterator_next(rrule_itr)) {
-
-            /* if we have iterated past end time,
-               then no need to check any further */
+            /* if we have iterated past end time, then no need to check any further */
             if (icaltime_compare(rrule_time, end) > 0)
                 break;
 
@@ -883,50 +964,45 @@ void icalcomponent_foreach_recurrence(icalcomponent *comp,
                                             icaltimezone_get_utc_timezone());
             recurspan.end = recurspan.start + dtduration;
 
-            /* save the iterator ICK! */
+      /** save the iterator ICK! **/
             property_iterator = comp->property_iterator;
 
-            if (!icalproperty_recurrence_is_excluded(comp,
-                                                     &dtstart, &rrule_time)) {
-                /* call callback action */
+            if (!icalproperty_recurrence_is_excluded(comp, &dtstart, &rrule_time)) {
+        /** call callback action **/
                 if (icaltime_span_overlaps(&recurspan, &limit_span))
                     (*callback) (comp, &recurspan, callback_data);
             }
             comp->property_iterator = property_iterator;
-        }   /* end of iteration over a specific RRULE */
+        }       /* end of iteration over a specific RRULE */
 
         icalrecur_iterator_free(rrule_itr);
     }   /* end of RRULE loop */
 
-    /* Now process RDATE entries */
+  /** Now process RDATE entries **/
     for (rdate = icalcomponent_get_first_property(comp, ICAL_RDATE_PROPERTY);
-         rdate != NULL;
-         rdate = icalcomponent_get_next_property(comp, ICAL_RDATE_PROPERTY)) {
+         rdate != NULL; rdate = icalcomponent_get_next_property(comp, ICAL_RDATE_PROPERTY)) {
 
-        struct icaldatetimeperiodtype rdate_period =
-            icalproperty_get_rdate(rdate);
+        struct icaldatetimeperiodtype rdate_period = icalproperty_get_rdate(rdate);
 
-        /* RDATES can specify raw datetimes, periods, or dates.
-            we only support raw datetimes for now..
+    /** RDATES can specify raw datetimes, periods, or dates.
+        we only support raw datetimes for now..
 
-            @todo Add support for other types */
+        @todo Add support for other types **/
 
         if (icaltime_is_null_time(rdate_period.time))
             continue;
 
         recurspan.start =
             icaltime_as_timet_with_zone(rdate_period.time,
-                                        rdate_period.time.zone ?
-                                        rdate_period.time.zone :
+                                        rdate_period.time.zone ? rdate_period.time.zone :
                                         icaltimezone_get_utc_timezone());
         recurspan.end = recurspan.start + dtduration;
 
-        /* save the iterator ICK! */
+    /** save the iterator ICK! **/
         property_iterator = comp->property_iterator;
 
-        if (!icalproperty_recurrence_is_excluded(comp,
-                                                 &dtstart, &rdate_period.time)) {
-            /* call callback action */
+        if (!icalproperty_recurrence_is_excluded(comp, &dtstart, &rdate_period.time)) {
+      /** call callback action **/
             if (icaltime_span_overlaps(&recurspan, &limit_span))
                 (*callback) (comp, &recurspan, callback_data);
         }
@@ -940,6 +1016,12 @@ int icalcomponent_check_restrictions(icalcomponent *comp)
     return icalrestriction_check(comp);
 }
 
+/** @brief returns the number of errors encountered parsing the data
+ *
+ * This function counts the number times the X-LIC-ERROR occurs
+ * in the data structure.
+ */
+
 int icalcomponent_count_errors(icalcomponent *component)
 {
     int errors = 0;
@@ -1266,6 +1348,9 @@ icalcomponent *icalcomponent_get_inner(icalcomponent *comp)
     }
 }
 
+/** @brief sets the METHOD property to the given method
+ */
+
 void icalcomponent_set_method(icalcomponent *comp, icalproperty_method method)
 {
     icalproperty *prop = icalcomponent_get_first_property(comp, ICAL_METHOD_PROPERTY);
@@ -1278,6 +1363,9 @@ void icalcomponent_set_method(icalcomponent *comp, icalproperty_method method)
     icalproperty_set_method(prop, method);
 }
 
+/** @brief returns the METHOD property
+ */
+
 icalproperty_method icalcomponent_get_method(icalcomponent *comp)
 {
     icalproperty *prop = icalcomponent_get_first_property(comp, ICAL_METHOD_PROPERTY);
@@ -1300,6 +1388,11 @@ if (inner == 0) { \
 } \
 prop = icalcomponent_get_first_property(inner, p_kind);
 
+/**     @brief Set DTSTART property to given icaltime
+ *
+ *      This method respects the icaltime type (DATE vs DATE-TIME) and
+ *      timezone (or lack thereof).
+ */
 void icalcomponent_set_dtstart(icalcomponent *comp, struct icaltimetype v)
 {
     const char *tzid;
@@ -1320,6 +1413,52 @@ void icalcomponent_set_dtstart(icalcomponent *comp, struct icaltimetype v)
     }
 }
 
+/**     @brief Get a DATE or DATE-TIME property as an icaltime
+ *
+ *      If the property is a DATE-TIME with a timezone parameter and a
+ *      corresponding VTIMEZONE is present in the component, the
+ *      returned component will already be in the correct timezone;
+ *      otherwise the caller is responsible for converting it.
+ *
+ *      FIXME this is useless until we can flag the failure
+ */
+static struct icaltimetype icalcomponent_get_datetime(icalcomponent *comp, icalproperty *prop)
+{
+    icalcomponent *c;
+    icalparameter *param;
+    struct icaltimetype ret;
+
+    ret = icalvalue_get_datetime(icalproperty_get_value(prop));
+
+    if ((param = icalproperty_get_first_parameter(prop, ICAL_TZID_PARAMETER)) != NULL) {
+        const char *tzid = icalparameter_get_tzid(param);
+        icaltimezone *tz = NULL;
+
+        for (c = comp; c != NULL; c = icalcomponent_get_parent(c)) {
+            tz = icalcomponent_get_timezone(c, tzid);
+            if (tz != NULL)
+                break;
+        }
+
+        if (tz == NULL)
+            tz = icaltimezone_get_builtin_timezone_from_tzid(tzid);
+
+        if (tz != NULL)
+            ret = icaltime_set_timezone(&ret, tz);
+    }
+
+    return ret;
+}
+
+/**     @brief Get DTSTART property as an icaltime
+ *
+ *      If DTSTART is a DATE-TIME with a timezone parameter and a
+ *      corresponding VTIMEZONE is present in the component, the
+ *      returned component will already be in the correct timezone;
+ *      otherwise the caller is responsible for converting it.
+ *
+ *      FIXME this is useless until we can flag the failure
+ */
 struct icaltimetype icalcomponent_get_dtstart(icalcomponent *comp)
 {
     icalcomponent *inner = icalcomponent_get_inner(comp);
@@ -1330,32 +1469,31 @@ struct icaltimetype icalcomponent_get_dtstart(icalcomponent *comp)
         return icaltime_null_time();
     }
 
-    return icalproperty_get_datetime_with_component(prop, comp);
+    return icalcomponent_get_datetime(comp, prop);
 }
 
+/**     @brief Get DTEND property as an icaltime
+ *
+ *      If a DTEND property is not present but a DURATION is, we use
+ *      that to determine the proper end.
+ *
+ *      If DTSTART is a DATE-TIME with a timezone parameter and a
+ *      corresponding VTIMEZONE is present in the component, the
+ *      returned component will already be in the correct timezone;
+ *      otherwise the caller is responsible for converting it.
+ *
+ *      FIXME this is useless until we can flag the failure
+ */
 struct icaltimetype icalcomponent_get_dtend(icalcomponent *comp)
 {
     icalcomponent *inner = icalcomponent_get_inner(comp);
-    const icalcomponent_kind kind = icalcomponent_isa(inner);
-    icalproperty *end_prop, *dur_prop;
-    struct icaltimetype ret;
+    icalproperty *end_prop = icalcomponent_get_first_property(inner, ICAL_DTEND_PROPERTY);
+    icalproperty *dur_prop = icalcomponent_get_first_property(inner, ICAL_DURATION_PROPERTY);
+    struct icaltimetype ret = icaltime_null_time();
 
-    switch(kind) {
-    case ICAL_VAVAILABILITY_COMPONENT:
-    case ICAL_VEVENT_COMPONENT:
-    case ICAL_VFREEBUSY_COMPONENT:
-    case ICAL_XAVAILABLE_COMPONENT:
-        break;
-    default:
-        return icaltime_null_time();
-    }
-
-    end_prop = icalcomponent_get_first_property(inner, ICAL_DTEND_PROPERTY);
-    dur_prop = icalcomponent_get_first_property(inner, ICAL_DURATION_PROPERTY);
-
-    if (end_prop != 0 && dur_prop == 0) {
-        ret = icalproperty_get_datetime_with_component(end_prop, comp);
-    } else if (end_prop == 0 && dur_prop != 0) {
+    if (end_prop != 0) {
+        ret = icalcomponent_get_datetime(comp, end_prop);
+    } else if (dur_prop != 0) {
 
         struct icaltimetype start = icalcomponent_get_dtstart(inner);
         struct icaldurationtype duration;
@@ -1368,28 +1506,20 @@ struct icaltimetype icalcomponent_get_dtend(icalcomponent *comp)
         }
 
         ret = icaltime_add(start, duration);
-    } else if (end_prop == 0 && dur_prop == 0) {
-        if (kind == ICAL_VEVENT_COMPONENT) {
-            struct icaltimetype start = icalcomponent_get_dtstart(inner);
-            if (icaltime_is_date(start)) {
-                struct icaldurationtype duration = icaldurationtype_null_duration();
-                duration.days = 1;
-                ret = icaltime_add(start, duration);
-            } else {
-                ret = start;
-            }
-        } else {
-            ret = icaltime_null_time();
-        }
-    } else {
-        /* Error, both duration and dtend have been specified */
-        icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
-        ret = icaltime_null_time();
     }
 
     return ret;
 }
 
+/**     @brief Set DTEND property to given icaltime
+ *
+ *      This method respects the icaltime type (DATE vs DATE-TIME) and
+ *      timezone (or lack thereof).
+ *
+ *      This also checks that a DURATION property isn't already there,
+ *      and returns an error if it is. It's the caller's responsibility
+ *      to remove it.
+ */
 void icalcomponent_set_dtend(icalcomponent *comp, struct icaltimetype v)
 {
     const char *tzid;
@@ -1415,6 +1545,15 @@ void icalcomponent_set_dtend(icalcomponent *comp, struct icaltimetype v)
     }
 }
 
+/**     @brief Set DURATION property to given icalduration
+ *
+ *      This method respects the icaltime type (DATE vs DATE-TIME) and
+ *      timezone (or lack thereof).
+ *
+ *      This also checks that a DTEND property isn't already there,
+ *      and returns an error if it is. It's the caller's responsibility
+ *      to remove it.
+ */
 void icalcomponent_set_duration(icalcomponent *comp, struct icaldurationtype v)
 {
     ICALSETUPSET(ICAL_DURATION_PROPERTY);
@@ -1432,35 +1571,20 @@ void icalcomponent_set_duration(icalcomponent *comp, struct icaldurationtype v)
     }
 }
 
+/**     @brief Get DURATION property as an icalduration
+ *
+ *      If a DURATION property is not present but a DTEND is, we use
+ *      that to determine the proper end.
+ */
 struct icaldurationtype icalcomponent_get_duration(icalcomponent *comp)
 {
     icalcomponent *inner = icalcomponent_get_inner(comp);
-    const icalcomponent_kind kind = icalcomponent_isa(inner);
-    icalproperty *end_prop, *dur_prop;
-    struct icaltimetype end;
-    struct icaldurationtype ret;
 
-    switch(kind) {
-    case ICAL_VAVAILABILITY_COMPONENT:
-    case ICAL_VEVENT_COMPONENT:
-    case ICAL_XAVAILABLE_COMPONENT:
-        end_prop = icalcomponent_get_first_property(inner, ICAL_DTEND_PROPERTY);
-        if (end_prop) {
-            end = icalcomponent_get_dtend(inner);
-        }
-        break;
-    case ICAL_VTODO_COMPONENT:
-        end_prop = icalcomponent_get_first_property(inner, ICAL_DUE_PROPERTY);
-        if (end_prop) {
-            end = icalcomponent_get_due(inner);
-        }
-        break;
-    default:
-        /* The libical API is used incorrectly */
-        return icaldurationtype_null_duration();
-    }
+    icalproperty *end_prop = icalcomponent_get_first_property(inner, ICAL_DTEND_PROPERTY);
 
-    dur_prop = icalcomponent_get_first_property(inner, ICAL_DURATION_PROPERTY);
+    icalproperty *dur_prop = icalcomponent_get_first_property(inner, ICAL_DURATION_PROPERTY);
+
+    struct icaldurationtype ret = icaldurationtype_null_duration();
 
     if (dur_prop != 0 && end_prop == 0) {
         ret = icalproperty_get_duration(dur_prop);
@@ -1469,19 +1593,13 @@ struct icaldurationtype icalcomponent_get_duration(icalcomponent *comp)
         /**
          * FIXME
          * We assume DTSTART and DTEND are not in different time zones.
-         * The standard actually allows different time zones.
+         * Does the standard actually guarantee this?
          */
         struct icaltimetype start = icalcomponent_get_dtstart(inner);
+        struct icaltimetype end = icalcomponent_get_dtend(inner);
 
         ret = icaltime_subtract(end, start);
-    } else if (end_prop == 0 && dur_prop == 0) {
-        struct icaltimetype start = icalcomponent_get_dtstart(inner);
-        ret = icaldurationtype_null_duration();
-        if (kind == ICAL_VEVENT_COMPONENT && icaltime_is_date(start)) {
-            ret.days = 1;
-        }
     } else {
-        ret = icaldurationtype_null_duration();
         /* Error, both duration and dtend have been specified */
         icalerror_set_errno(ICAL_MALFORMEDDATA_ERROR);
     }
@@ -1556,7 +1674,7 @@ void icalcomponent_set_comment(icalcomponent *comp, const char *v)
         icalcomponent_add_property(inner, prop);
     }
 
-    icalproperty_set_comment(prop, v);
+    icalproperty_set_summary(prop, v);
 }
 
 const char *icalcomponent_get_comment(icalcomponent *comp)
@@ -1591,7 +1709,7 @@ void icalcomponent_set_uid(icalcomponent *comp, const char *v)
         icalcomponent_add_property(inner, prop);
     }
 
-    icalproperty_set_uid(prop, v);
+    icalproperty_set_summary(prop, v);
 }
 
 const char *icalcomponent_get_uid(icalcomponent *comp)
@@ -1894,6 +2012,11 @@ icalcomponent *icalcomponent_new_xpatch(void)
  * Timezone stuff.
  */
 
+/**
+ *  This takes 2 VCALENDAR components and merges the second one into the first,
+ *  resolving any problems with conflicting TZIDs. comp_to_merge will no
+ *  longer exist after calling this function.
+ */
 void icalcomponent_merge_component(icalcomponent *comp, icalcomponent *comp_to_merge)
 {
     icalcomponent *subcomp, *next_subcomp;
@@ -2139,6 +2262,9 @@ static void icalcomponent_rename_tzids_callback(icalparameter *param, void *data
     }
 }
 
+/**
+ * Calls the given function for each TZID parameter found in the component.
+ */
 void icalcomponent_foreach_tzid(icalcomponent *comp,
                                 void (*callback) (icalparameter *param, void *data),
                                 void *callback_data)
@@ -2176,6 +2302,10 @@ void icalcomponent_foreach_tzid(icalcomponent *comp,
     }
 }
 
+/**
+ *  Returns the icaltimezone from the component corresponding to the given
+ *  TZID, or NULL if the component does not have a corresponding VTIMEZONE.
+ */
 icaltimezone *icalcomponent_get_timezone(icalcomponent *comp, const char *tzid)
 {
     icaltimezone *zone;
@@ -2193,7 +2323,7 @@ icaltimezone *icalcomponent_get_timezone(icalcomponent *comp, const char *tzid)
     }
 
     /* Do a simple binary search. */
-    lower = 0;
+    lower = middle = 0;
     upper = comp->timezones->num_elements;
 
     while (lower < upper) {
@@ -2298,7 +2428,7 @@ static int icalcomponent_compare_vtimezones(icalcomponent *vtimezone1, icalcompo
 }
 
 /**
- * @brief Sets the RELCALID property of a component.
+ * @brief set the RELCALID property of a component.
  *
  * @param comp    Valid calendar component.
  * @param v       Relcalid URL value
@@ -2317,7 +2447,7 @@ void icalcomponent_set_relcalid(icalcomponent *comp, const char *v)
 }
 
 /**
- * @brief Gets the RELCALID property of a component.
+ * @brief get the RELCALID property of a component.
  *
  * @param comp    Valid calendar component.
  */
@@ -2344,6 +2474,14 @@ const char *icalcomponent_get_relcalid(icalcomponent *comp)
     return icalproperty_get_relcalid(prop);
 }
 
+/** @brief Return the time a TODO task is DUE.
+ *
+ *  @param comp Valid calendar component.
+ *
+ *  Uses the DUE: property if it exists, otherwise we calculate the DUE
+ *  value by adding the task's duration to the DTSTART time
+ */
+
 struct icaltimetype icalcomponent_get_due(icalcomponent *comp)
 {
     icalcomponent *inner = icalcomponent_get_inner(comp);
@@ -2353,7 +2491,7 @@ struct icaltimetype icalcomponent_get_due(icalcomponent *comp)
     icalproperty *dur_prop = icalcomponent_get_first_property(inner, ICAL_DURATION_PROPERTY);
 
     if (due_prop != 0) {
-        return icalproperty_get_datetime_with_component(due_prop, comp);
+        return icalcomponent_get_datetime(comp, due_prop);
     } else if (dur_prop != 0) {
 
         struct icaltimetype start = icalcomponent_get_dtstart(inner);
@@ -2366,6 +2504,17 @@ struct icaltimetype icalcomponent_get_due(icalcomponent *comp)
     return icaltime_null_time();
 }
 
+/** @brief Set the due date of a VTODO task.
+ *
+ *  @param comp Valid VTODO component.
+ *  @param v    Valid due date time.
+ *
+ *  - If no duration or due properties then set the DUE property.
+ *  - If a DUE property is already set, then reset it to the value v.
+ *  - If a DURATION property is already set, then calculate the new
+ *    duration based on the supplied value of v.
+ */
+
 void icalcomponent_set_due(icalcomponent *comp, struct icaltimetype v)
 {
     const char *tzid;
@@ -2381,7 +2530,6 @@ void icalcomponent_set_due(icalcomponent *comp, struct icaltimetype v)
         icalcomponent_add_property(inner, due_prop);
     } else if (due_prop != 0) {
         icalproperty_set_due(due_prop, v);
-        icalproperty_remove_parameter_by_kind(due_prop, ICAL_TZID_PARAMETER);
     } else if (dur_prop != 0) {
         struct icaltimetype start = icalcomponent_get_dtstart(inner);
 
@@ -2397,12 +2545,6 @@ void icalcomponent_set_due(icalcomponent *comp, struct icaltimetype v)
     }
 }
 
-static int strcmpsafe(const char *a, const char *b)
-{
-    return strcmp((a == NULL ? "" : a),
-                  (b == NULL ? "" : b));
-}
-
 static int prop_compare(void *a, void *b)
 {
     icalproperty *p1 = (icalproperty*) a;
@@ -2418,8 +2560,8 @@ static int prop_compare(void *a, void *b)
         }
 
         if (r == 0) {
-            r = strcmpsafe(icalproperty_get_value_as_string(p1),
-                           icalproperty_get_value_as_string(p2));
+            r = strcmp(icalproperty_get_value_as_string(p1),
+                       icalproperty_get_value_as_string(p2));
         }
     }
 
@@ -2532,75 +2674,66 @@ void icalcomponent_normalize(icalcomponent *comp)
     pvl_list sorted_props = pvl_newlist();
     pvl_list sorted_comps = pvl_newlist();
     icalproperty *prop;
-    icalcomponent *sub;
+    icalcomponent *mycomp;
 
-    /* Normalize properties into sorted list */
     while ((prop = pvl_pop(comp->properties)) != 0) {
-        int nparams, remove = 0;
+        int nparams = icalproperty_count_parameters(prop);
+
+        /* Skip unparameterized properties having default values */
+        switch (icalproperty_isa(prop)) {
+        case ICAL_CALSCALE_PROPERTY:
+            if ((nparams == 0) &&
+                (strcmp("GREGORIAN", icalproperty_get_calscale(prop)) == 0)) {
+                continue;
+            }
+            break;
+
+        case ICAL_CLASS_PROPERTY:
+            if ((nparams == 0) &&
+                (icalproperty_get_class(prop) == ICAL_CLASS_PUBLIC)) {
+                continue;
+            }
+            break;
+
+        case ICAL_PRIORITY_PROPERTY:
+            if ((nparams == 0) && (icalproperty_get_priority(prop) == 0)) {
+                continue;
+            }
+            break;
+
+        case ICAL_TRANSP_PROPERTY:
+            if ((nparams == 0) &&
+                (icalproperty_get_transp(prop) == ICAL_TRANSP_OPAQUE)) {
+                continue;
+            }
+            break;
+
+        case ICAL_REPEAT_PROPERTY:
+            if ((nparams == 0) && (icalproperty_get_repeat(prop) == 0)) {
+                continue;
+            }
+            break;
+
+        case ICAL_SEQUENCE_PROPERTY:
+            if ((nparams == 0) && (icalproperty_get_sequence(prop) == 0)) {
+                continue;
+            }
+            break;
+
+        default:
+            break;
+        }
 
         icalproperty_normalize(prop);
-
-        nparams = icalproperty_count_parameters(prop);
-
-        /* Remove unparameterized properties having default values */
-        if (nparams == 0) {
-            switch (icalproperty_isa(prop)) {
-            case ICAL_CALSCALE_PROPERTY:
-                if (strcmp("GREGORIAN", icalproperty_get_calscale(prop)) == 0) {
-                    remove = 1;
-                }
-                break;
-
-            case ICAL_CLASS_PROPERTY:
-                if (icalproperty_get_class(prop) == ICAL_CLASS_PUBLIC) {
-                    remove = 1;
-                }
-                break;
-
-            case ICAL_PRIORITY_PROPERTY:
-                if (icalproperty_get_priority(prop) == 0) {
-                    remove = 1;
-                }
-                break;
-
-            case ICAL_TRANSP_PROPERTY:
-                if (icalproperty_get_transp(prop) == ICAL_TRANSP_OPAQUE) {
-                    remove = 1;
-                }
-                break;
-
-            case ICAL_REPEAT_PROPERTY:
-                if (icalproperty_get_repeat(prop) == 0) {
-                    remove = 1;
-                }
-                break;
-
-            case ICAL_SEQUENCE_PROPERTY:
-                if (icalproperty_get_sequence(prop) == 0) {
-                    remove = 1;
-                }
-                break;
-
-            default:
-                break;
-            }
-        }
-
-        if (remove) {
-            icalproperty_set_parent(prop, 0); // MUST NOT have a parent to free
-            icalproperty_free(prop);
-        } else {
-            pvl_insert_ordered(sorted_props, prop_compare, prop);
-        }
+        pvl_insert_ordered(sorted_props, prop_compare, prop);
     }
 
     pvl_free(comp->properties);
     comp->properties = sorted_props;
 
-    /* Normalize sub-components into sorted list */
-    while ((sub = pvl_pop(comp->components)) != 0) {
-        icalcomponent_normalize(sub);
-        pvl_insert_ordered(sorted_comps, comp_compare, sub);
+    while ((mycomp = pvl_pop(comp->components)) != 0) {
+        icalcomponent_normalize(mycomp);
+        pvl_insert_ordered(sorted_comps, comp_compare, mycomp);
     }
 
     pvl_free(comp->components);
