@@ -20,18 +20,20 @@
 #include "icalparameter_cxx.h"
 using namespace LibICal;
 
-ICalParameter::ICalParameter() : imp(icalparameter_new(ICAL_ANY_PARAMETER))
+ICalParameter::ICalParameter() throw(icalerrorenum)
+    : imp(icalparameter_new(ICAL_ANY_PARAMETER))
 {
 }
 
-ICalParameter::ICalParameter(const ICalParameter &v) : imp(icalparameter_new_clone(v.imp))
+ICalParameter::ICalParameter(const ICalParameter &v) throw(icalerrorenum)
+    : imp(icalparameter_new_clone(v.imp))
 {
     if (imp == NULL) {
         throw icalerrno;
     }
 }
 
-ICalParameter &ICalParameter::operator=(const ICalParameter &v)
+ICalParameter &ICalParameter::operator=(const ICalParameter &v)  throw(icalerrorenum)
 {
     if (this == &v) {
         return *this;
@@ -60,12 +62,13 @@ ICalParameter::~ICalParameter()
     }
 }
 
-ICalParameter::ICalParameter(icalparameter *v) : imp(v)
+ICalParameter::ICalParameter(icalparameter *v) throw(icalerrorenum)
+    : imp(v)
 {
 }
 
 /// Create from string of form "PARAMNAME=VALUE"
-ICalParameter::ICalParameter(const std::string &str)
+ICalParameter::ICalParameter(const std::string &str) throw(icalerrorenum)
     : imp(icalparameter_new_from_string(str.c_str()))
 {
     if (imp == NULL) {
@@ -74,7 +77,8 @@ ICalParameter::ICalParameter(const std::string &str)
 }
 
 /// Create from just the value, the part after the "="
-ICalParameter::ICalParameter(const icalparameter_kind &kind, const std::string &str)
+ICalParameter::ICalParameter(const icalparameter_kind &kind,
+                             const std::string &str) throw(icalerrorenum)
     : imp(icalparameter_new_from_value_string(kind, str.c_str()))
 {
     if (imp == NULL) {
@@ -82,14 +86,15 @@ ICalParameter::ICalParameter(const icalparameter_kind &kind, const std::string &
     }
 }
 
-ICalParameter::ICalParameter(const icalparameter_kind &kind) : imp(icalparameter_new(kind))
+ICalParameter::ICalParameter(const icalparameter_kind &kind) throw(icalerrorenum)
+    : imp(icalparameter_new(kind))
 {
     if (imp == NULL) {
         throw icalerrno;
     }
 }
 
-std::string ICalParameter::as_ical_string()
+std::string ICalParameter::as_ical_string() throw(icalerrorenum)
 {
     char *str = icalparameter_as_ical_string(imp);
 
