@@ -37,19 +37,20 @@ namespace LibICal
 class LIBICAL_ICAL_EXPORT ICalParameter
 {
 public:
-    ICalParameter();
-    ICalParameter(const ICalParameter &);
-    ICalParameter &operator=(const ICalParameter &);
+    ICalParameter() throw(icalerrorenum);
+    ICalParameter(const ICalParameter &) throw(icalerrorenum);
+    ICalParameter &operator=(const ICalParameter &) throw(icalerrorenum);
     ~ICalParameter();
 
-    explicit ICalParameter(icalparameter *v);
+    explicit ICalParameter(icalparameter *v) throw(icalerrorenum);
 
     // Create from string of form "PARAMNAME=VALUE"
-    explicit ICalParameter(const std::string &str);
+    explicit ICalParameter(const std::string &str) throw(icalerrorenum);
 
     // Create from just the value, the part after the "="
-    explicit ICalParameter(const icalparameter_kind &kind);
-    ICalParameter(const icalparameter_kind &kind, const std::string &str);
+    explicit ICalParameter(const icalparameter_kind &kind) throw(icalerrorenum);
+    ICalParameter(const icalparameter_kind &kind,
+                  const std::string &str) throw(icalerrorenum);
 
     operator  icalparameter *()
     {
@@ -59,7 +60,7 @@ public:
     void detach();
 
 public:
-    std::string as_ical_string();
+    std::string as_ical_string() throw(icalerrorenum);
     bool is_valid();
     icalparameter_kind isa();
     int isa_parameter(void *param);
