@@ -2,29 +2,30 @@
  FILE: icalparser.c
  CREATOR: eric 04 August 1999
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 
   The Initial Developer of the Original Code is Eric Busboom
  ======================================================================*/
@@ -44,10 +45,6 @@
 #include <stdlib.h>
 
 #define TMP_BUF_SIZE 80
-#define MAXIMUM_ALLOWED_PARAMETERS 100
-#define MAXIMUM_ALLOWED_MULTIPLE_VALUES 500
-
-static enum icalparser_ctrl icalparser_ctrl_g = ICALPARSER_CTRL_KEEP;
 
 struct icalparser_impl
 {
@@ -171,13 +168,9 @@ static char *parser_get_next_char(char c, char *str, int qm)
     return 0;
 }
 
-/** Makes a new tmp buffer out of a substring. */
+/** make a new tmp buffer out of a substring */
 static char *make_segment(char *start, char *end)
 {
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wstringop-truncation"
-#endif
     char *buf, *tmp;
     ptrdiff_t size = (ptrdiff_t)(end - start);
 
@@ -192,9 +185,6 @@ static char *make_segment(char *start, char *end)
     }
 
     return buf;
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic pop
-#endif
 }
 
 static char *parser_get_prop_name(char *line, char **end)
@@ -222,7 +212,7 @@ static char *parser_get_prop_name(char *line, char **end)
     return str;
 }
 
-/** Decode parameter value per RFC6868 */
+/* Decode parameter value per RFC6868 */
 static void parser_decode_param_value(char *value)
 {
     char *in, *out;
@@ -272,7 +262,7 @@ static int parser_get_param_name_stack(char *line, char *name, size_t name_lengt
         /* Dequote the value */
         next++;
 
-        end_quote = (*next == '"') ? next : parser_get_next_char('"', next, 0);
+        end_quote = parser_get_next_char('"', next, 0);
 
         if (end_quote == 0) {
             return 0;
@@ -319,7 +309,7 @@ static char *parser_get_param_name_heap(char *line, char **end)
     *end = next + 1;
     if (**end == '"') {
         *end = *end + 1;
-        next = (**end == '"') ? *end : parser_get_next_char('"', *end, 0);
+        next = parser_get_next_char('"', *end, 0);
         if (next == 0) {
             free(str);
             *end = NULL;
@@ -401,7 +391,7 @@ static char *parser_get_next_value(char *line, char **end, icalvalue_kind kind)
 
         next = parser_get_next_char(',', p, 1);
 
-        /* Unfortunately, RFC2445 allowed that for the RECUR value, COMMA
+        /* Unforunately, RFC2445 allowed that for the RECUR value, COMMA
            could both separate digits in a list, and it could separate
            multiple recurrence specifications. This is not a friendly
            part of the spec and was deprecated in RFC5545. The following
@@ -418,8 +408,8 @@ static char *parser_get_next_value(char *line, char **end, icalvalue_kind kind)
                 continue;
             }
         }
-        /* ignore all commas for query and x values. select dtstart, dtend etc ... */
-        else if (kind == ICAL_QUERY_VALUE || kind == ICAL_X_VALUE) {
+        /* ignore all , for query value. select dtstart, dtend etc ... */
+        else if (kind == ICAL_QUERY_VALUE) {
             if (next != 0) {
                 p = next + 1;
                 continue;
@@ -482,8 +472,12 @@ static char *parser_get_next_parameter(char *line, char **end)
     }
 }
 
+/**
+ * Get a single property line, from the property name through the
+ * final new line, and include any continuation lines
+ */
 char *icalparser_get_line(icalparser *parser,
-                          icalparser_line_gen_func line_gen_func)
+                          char *(*line_gen_func) (char *s, size_t size, void *d))
 {
     char *line;
     char *line_p;
@@ -550,7 +544,7 @@ char *icalparser_get_line(icalparser *parser,
             if (parser->temp[0] == '\0') {
 
                 if (line[0] != '\0') {
-                    /* There is data in the output, so fall through and process it */
+                    /* There is data in the output, so fall trhough and process it */
                     break;
                 } else {
                     /* No data in output; return and signal that there
@@ -613,7 +607,7 @@ static void insert_error(icalcomponent *comp, const char *text,
 
     icalcomponent_add_property(
         comp,
-        icalproperty_vanew_xlicerror(temp, icalparameter_new_xlicerrortype(type), (void *)0));
+        icalproperty_vanew_xlicerror(temp, icalparameter_new_xlicerrortype(type), 0));
 }
 
 static int line_is_blank(char *line)
@@ -632,7 +626,7 @@ static int line_is_blank(char *line)
 }
 
 icalcomponent *icalparser_parse(icalparser *parser,
-                                icalparser_line_gen_func line_gen_func)
+                                char *(*line_gen_func) (char *s, size_t size, void *d))
 {
     char *line;
     icalcomponent *c = 0;
@@ -695,7 +689,6 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
 {
     char *str;
     char *end;
-    int pcount = 0;
     int vcount = 0;
     icalproperty *prop;
     icalproperty_kind prop_kind;
@@ -713,47 +706,6 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
         return 0;
     }
 
-    if (icalparser_ctrl_g != ICALPARSER_CTRL_KEEP) {
-        static const unsigned char is_icalctrl[256] = {
-            1, 1, 1, 1, 1, 1, 1, 1, 1, 0, 0, 1, 1, 0, 1, 1,
-            1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 1,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
-            0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0
-        };
-
-        char *c, *d;
-        for (c = d = line; *c; c++) {
-            if (!is_icalctrl[(unsigned char)*c]) {
-                *d++ = *c;
-            } else if (icalparser_ctrl_g == ICALPARSER_CTRL_OMIT) {
-                // omit CTRL character
-            } else {
-                icalcomponent *tail = pvl_data(pvl_tail(parser->components));
-                if (tail) {
-                    insert_error(
-                            tail, line,
-                            "Content line contains invalid CONTROL characters",
-                            ICAL_XLICERRORTYPE_COMPONENTPARSEERROR);
-                }
-                parser->state = ICALPARSER_ERROR;
-                return 0;
-            }
-        }
-        *d = '\0';
-    }
-
     /* Begin by getting the property name at the start of the line. The
        property name may end up being "BEGIN" or "END" in which case it
        is not really a property, but the marker for the start or end of
@@ -831,15 +783,8 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
         icalmemory_free_buffer(str);
         str = NULL;
 
-        if (parser->level < 0) {
-            // Encountered an END before any BEGIN, this must be invalid data
-            icalerror_warn("Encountered END before BEGIN");
-
-            parser->state = ICALPARSER_ERROR;
-            parser->level = 0;
-            return 0;
-        } else if (parser->level == 0) {
-            /* Return the component if we are back to the 0th level */
+        /* Return the component if we are back to the 0th level */
+        if (parser->level == 0) {
             icalcomponent *rtrn;
 
             if (pvl_count(parser->components) != 0) {
@@ -919,7 +864,7 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
 
     /* Now, add any parameters to the last property */
 
-    while (pcount < MAXIMUM_ALLOWED_PARAMETERS) {
+    while (1) {
         if (*(end - 1) == ':') {
             /* if the last separator was a ":" and the value is a
                URL, icalparser_get_next_parameter will find the
@@ -951,7 +896,7 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
 
                 if (name_heap == 0) {
                     /* 'tail' defined above */
-                    insert_error(tail, str, "Can't parse parameter name",
+                    insert_error(tail, str, "Cant parse parameter name",
                                  ICAL_XLICERRORTYPE_PARAMETERNAMEPARSEERROR);
                     tail = 0;
                     break;
@@ -1040,11 +985,6 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
                 /* Reparse the parameter name and value with the new segment */
                 if (!parser_get_param_name_stack(str, name_stack, sizeof(name_stack),
                                                  pvalue_stack, sizeof(pvalue_stack))) {
-                    if (pvalue_heap) {
-                        icalmemory_free_buffer(pvalue_heap);
-                        pvalue_heap = 0;
-                        pvalue = 0;
-                    }
                     if (name_heap) {
                         icalmemory_free_buffer(name_heap);
                         name = 0;
@@ -1062,7 +1002,7 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
                 /* Change for mozilla */
                 /* have the option of being flexible towards unsupported parameters */
 #if ICAL_ERRORS_ARE_FATAL == 1
-                insert_error(tail, str, "Can't parse parameter name",
+                insert_error(tail, str, "Cant parse parameter name",
                              ICAL_XLICERRORTYPE_PARAMETERNAMEPARSEERROR);
                 tail = 0;
                 parser->state = ICALPARSER_ERROR;
@@ -1104,7 +1044,7 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
 
             if (param == 0) {
                 /* 'tail' defined above */
-                insert_error(tail, str, "Can't parse parameter value",
+                insert_error(tail, str, "Cant parse parameter value",
                              ICAL_XLICERRORTYPE_PARAMETERVALUEPARSEERROR);
 
                 tail = 0;
@@ -1143,7 +1083,6 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
 
                     icalmemory_free_buffer(str);
                     str = NULL;
-                    pcount++;
                     continue;
                 }
             }
@@ -1153,7 +1092,6 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
             tail = 0;
             icalmemory_free_buffer(str);
             str = NULL;
-            pcount++;
 
         } else {
             /* str is NULL */
@@ -1171,7 +1109,7 @@ icalcomponent *icalparser_add_line(icalparser *parser, char *line)
        parameter and add one part of the value to each clone */
 
     vcount = 0;
-    while (vcount < MAXIMUM_ALLOWED_MULTIPLE_VALUES) {
+    while (1) {
         /* Only some properties can have multiple values. This list was taken
            from rfc5545. Also added the x-properties, because the spec actually
            says that commas should be escaped. For x-properties, other apps may
@@ -1335,13 +1273,6 @@ char *icalparser_string_line_generator(char *out, size_t buf_size, void *d)
 
     if (data->pos == 0) {
         data->pos = data->str;
-
-        /* Skip the UTF-8 marker at the beginning of the string */
-        if (((unsigned char) data->pos[0]) == 0xEF &&
-            ((unsigned char) data->pos[1]) == 0xBB &&
-            ((unsigned char) data->pos[2]) == 0xBF) {
-            data->pos += 3;
-        }
     }
 
     /* If the pointer is at the end of the string, we are done */
@@ -1370,14 +1301,7 @@ char *icalparser_string_line_generator(char *out, size_t buf_size, void *d)
         size = buf_size - 1;
     }
 
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wstringop-truncation"
-#endif
     strncpy(out, data->pos, size);
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic pop
-#endif
 
     if(replace_cr) {
         *(out + size - 1) = '\n';
@@ -1413,13 +1337,3 @@ icalcomponent *icalparser_parse_string(const char *str)
 
     return c;
 }
-
-enum icalparser_ctrl icalparser_get_ctrl(void)
-{
-    return icalparser_ctrl_g;
-}
-
-void icalparser_set_ctrl(enum icalparser_ctrl ctrl)
-{
-    icalparser_ctrl_g = ctrl;
-}
