@@ -5,7 +5,7 @@
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
      http://www.softwarestudio.org
 
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
@@ -13,7 +13,7 @@
 
  Or:
 
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
 
   The original code is icalproperty.c
@@ -23,7 +23,7 @@
 #include <config.h>
 #endif
 
-#include "icalproperty.h"
+#include "icalproperty_p.h"
 #include "icalcomponent.h"
 #include "icalerror.h"
 #include "icalmemory.h"
@@ -316,33 +316,33 @@ static char *fold_property_line(char *text)
    this one, so we need to do it here */
 static const char *icalproperty_get_value_kind(icalproperty *prop)
 {
-    const char *kind_string = 0;
+    const char *kind_string = NULL;
+    icalvalue_kind kind = ICAL_NO_VALUE;
+    icalparameter *val_param =
+        icalproperty_get_first_parameter(prop, ICAL_VALUE_PARAMETER);
 
-    icalparameter *orig_val_param = icalproperty_get_first_parameter(prop, ICAL_VALUE_PARAMETER);
-
-    icalvalue *value = icalproperty_get_value(prop);
-
-    icalvalue_kind orig_kind = ICAL_NO_VALUE;
-
-    icalvalue_kind this_kind = ICAL_NO_VALUE;
-
-    icalvalue_kind default_kind = icalproperty_kind_to_value_kind(prop->kind);
-
-    if (orig_val_param) {
-        orig_kind = icalparameter_value_to_value_kind(icalparameter_get_value(orig_val_param));
+    if (val_param) {
+        kind = icalparameter_value_to_value_kind(icalparameter_get_value(val_param));
     }
 
-    if (value != 0) {
-        this_kind = icalvalue_isa(value);
+    if (kind == ICAL_NO_VALUE) {
+        icalvalue *value = icalproperty_get_value(prop);
+
+        kind = icalvalue_isa(value);
+
+        if (kind == ICAL_ATTACH_VALUE) {
+            icalattach *a = icalvalue_get_attach(value);
+
+            kind = icalattach_get_is_url(a) ? ICAL_URI_VALUE : ICAL_BINARY_VALUE;
+        }
     }
 
-    if (orig_kind != ICAL_NO_VALUE) {
-        kind_string = icalvalue_kind_to_string(orig_kind);
-    } else if (this_kind != default_kind && this_kind != ICAL_NO_VALUE) {
+    if (kind != ICAL_NO_VALUE &&
+        !icalproperty_value_kind_is_default(prop->kind, kind)) {
         /* Not the default, so it must be specified */
-        kind_string = icalvalue_kind_to_string(this_kind);
+        kind_string = icalvalue_kind_to_string(kind);
     } else {
-        /* Don'tinclude the VALUE parameter at all */
+        /* Don't include the VALUE parameter at all */
     }
 
     return kind_string;
@@ -625,17 +625,6 @@ char *icalproperty_get_parameter_as_string_r(icalproperty *prop, const char *nam
     return str;
 }
 
-/** @see icalproperty_remove_parameter_by_kind()
- *
- *  @deprecated Please use icalproperty_remove_parameter_by_kind()
- *              instead.
- */
-
-void icalproperty_remove_parameter(icalproperty *prop, icalparameter_kind kind)
-{
-    icalproperty_remove_parameter_by_kind(prop, kind);
-}
-
 /** @brief Remove all parameters with the specified kind.
  *
  *  @param prop   A valid icalproperty.
@@ -948,3 +937,115 @@ icalcomponent *icalproperty_get_parent(const icalproperty *property)
 
     return property->parent;
 }
+
+static int param_compare(void *a, void *b)
+{
+    /* XXX  Need to sort values for multi-valued parameters (e.g. MEMBER) */
+    return strcmp(icalparameter_as_ical_string((icalparameter *) a),
+                  icalparameter_as_ical_string((icalparameter *) b));
+}
+
+void icalproperty_normalize(icalproperty *prop)
+{
+    icalproperty_kind prop_kind = icalproperty_isa(prop);
+    pvl_list sorted_params = pvl_newlist();
+    icalparameter *param;
+
+    while ((param = pvl_pop(prop->parameters)) != 0) {
+        /* Skip parameters having default values */
+        switch (icalparameter_isa(param)) {
+        case ICAL_VALUE_PARAMETER:
+            /* Skip VALUE parameters for default property value types */
+            switch (prop_kind) {
+            case ICAL_ATTACH_PROPERTY:
+                if (icalparameter_get_value(param) == ICAL_VALUE_URI) {
+                    continue;
+                }
+                break;
+
+            case ICAL_DTEND_PROPERTY:
+            case ICAL_DUE_PROPERTY:
+            case ICAL_DTSTART_PROPERTY:
+            case ICAL_EXDATE_PROPERTY:
+            case ICAL_RDATE_PROPERTY:
+            case ICAL_RECURRENCEID_PROPERTY:
+                if (icalparameter_get_value(param) == ICAL_VALUE_DATETIME) {
+                    continue;
+                }
+                break;
+
+            case ICAL_DURATION_PROPERTY:
+                if (icalparameter_get_value(param) == ICAL_VALUE_DURATION) {
+                    continue;
+                }
+                break;
+
+            default:
+                break;
+            }
+            break;
+
+        case ICAL_CUTYPE_PARAMETER:
+            if (icalparameter_get_cutype(param) == ICAL_CUTYPE_INDIVIDUAL) {
+                continue;
+            }
+            break;
+
+        case ICAL_ENCODING_PARAMETER:
+            if (icalparameter_get_encoding(param) == ICAL_ENCODING_8BIT) {
+                continue;
+            }
+            break;
+
+        case ICAL_FBTYPE_PARAMETER:
+            if (icalparameter_get_fbtype(param) == ICAL_FBTYPE_BUSY) {
+                continue;
+            }
+            break;
+
+        case ICAL_PARTSTAT_PARAMETER:
+            if (icalparameter_get_partstat(param) == ICAL_PARTSTAT_NEEDSACTION) {
+                continue;
+            }
+            break;
+
+        case ICAL_RELATED_PARAMETER:
+            if (icalparameter_get_related(param) == ICAL_RELATED_START) {
+                continue;
+            }
+            break;
+
+        case ICAL_RELTYPE_PARAMETER:
+            if (icalparameter_get_reltype(param) == ICAL_RELTYPE_PARENT) {
+                continue;
+            }
+            break;
+
+        case ICAL_ROLE_PARAMETER:
+            if (icalparameter_get_role(param) == ICAL_ROLE_REQPARTICIPANT) {
+                continue;
+            }
+            break;
+
+        case ICAL_RSVP_PARAMETER:
+            if (icalparameter_get_rsvp(param) == ICAL_RSVP_FALSE) {
+                continue;
+            }
+            break;
+
+        case ICAL_SCHEDULEAGENT_PARAMETER:
+            if (icalparameter_get_scheduleagent(param) == ICAL_SCHEDULEAGENT_SERVER) {
+                continue;
+            }
+            break;
+
+        default:
+            break;
+        }
+
+        pvl_insert_ordered(sorted_params, param_compare, param);
+    }
+
+    pvl_free(prop->parameters);
+    prop->parameters = sorted_params;
+}
