@@ -9,12 +9,12 @@
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
  */
 
 #include "icalproperty_cxx.h"
@@ -26,14 +26,15 @@ ICalProperty::ICalProperty() : imp(icalproperty_new(ICAL_ANY_PROPERTY))
 {
 }
 
-ICalProperty::ICalProperty(const ICalProperty &v) : imp(icalproperty_new_clone(v.imp))
+ICalProperty::ICalProperty(const ICalProperty &v) throw(icalerrorenum)
+    : imp(icalproperty_new_clone(v.imp))
 {
     if (imp == NULL) {
         throw icalerrno;
     }
 }
 
-ICalProperty &ICalProperty::operator=(const ICalProperty &v)
+ICalProperty &ICalProperty::operator=(const ICalProperty &v) throw(icalerrorenum)
 {
     if (this == &v) {
         return *this;
@@ -66,7 +67,7 @@ ICalProperty::ICalProperty(icalproperty *v) : imp(v)
 {
 }
 
-ICalProperty::ICalProperty(std::string str) //NOLINT TODO:V3.1:pass const ref
+ICalProperty::ICalProperty(std::string str)
     : imp(icalproperty_new_from_string(str.c_str()))
 {
 }
@@ -167,7 +168,7 @@ std::string ICalProperty::get_value_as_string()
     return static_cast<std::string>(icalproperty_get_value_as_string(imp));
 }
 
-/** Returns the name of the property -- the type name converted to a
+/** Return the name of the property -- the type name converted to a
  *  string, or the value of get_x_name if the type is X property
  */
 std::string ICalProperty::get_name() const
