@@ -5,7 +5,7 @@
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
      http://www.softwarestudio.org
 
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
@@ -13,7 +13,7 @@
 
  Or:
 
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
 ========================================================================*/
 
@@ -45,7 +45,7 @@ Or, just make them up:
 2) Create an iterator
 
 @code
-        icalrecur_iterator* ritr;
+        icalrecur_iterator *ritr;
         ritr = icalrecur_iterator_new(recur,start);
 @endcode
 
@@ -229,10 +229,18 @@ LIBICAL_ICAL_EXPORT char *icalrecurrencetype_as_string_r(struct icalrecurrencety
 
 typedef struct icalrecur_iterator_impl icalrecur_iterator;
 
-/** Create a new recurrence rule iterator */
+/** Create a new recurrence rule iterator, starting at DTSTART */
 LIBICAL_ICAL_EXPORT icalrecur_iterator *icalrecur_iterator_new(struct icalrecurrencetype rule,
                                                                struct icaltimetype dtstart);
 
+/** Set the date-time at which the iterator will start,
+ *  where 'start' is a value between DTSTART and UNTIL.
+ *
+ *  NOTE: CAN NOT be used with RRULEs that contain COUNT.
+ */
+LIBICAL_ICAL_EXPORT int icalrecur_iterator_set_start(icalrecur_iterator *impl,
+                                                     struct icaltimetype start);
+
 /** Get the next occurrence from an iterator */
 LIBICAL_ICAL_EXPORT struct icaltimetype icalrecur_iterator_next(icalrecur_iterator *);
 
@@ -243,7 +251,7 @@ LIBICAL_ICAL_EXPORT void icalrecur_iterator_free(icalrecur_iterator *);
  * Fills array up with at most 'count' time_t values, each
  *  representing an occurrence time in seconds past the POSIX epoch
  */
-LIBICAL_ICAL_EXPORT int icalrecur_expand_recurrence(char *rule, time_t start,
-                                                    int count, time_t * array);
+LIBICAL_ICAL_EXPORT int icalrecur_expand_recurrence(const char *rule, time_t start,
+                                                    int count, time_t *array);
 
 #endif
