@@ -2,18 +2,19 @@
  FILE: icaltypes.c
  CREATOR: eric 16 May 1999
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
  ======================================================================*/
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -29,7 +30,6 @@
 #include <pthread.h>
 static pthread_mutex_t unk_token_mutex = PTHREAD_MUTEX_INITIALIZER;
 #endif
-#include <ctype.h>
 
 static ical_unknown_token_handling unknownTokenHandling = ICAL_TREAT_AS_ERROR;
 
@@ -102,7 +102,7 @@ struct icaltriggertype icaltriggertype_from_string(const char *str)
 
 struct icalreqstattype icalreqstattype_from_string(const char *str)
 {
-    const char *s, *p1, *p2;
+    const char *p1, *p2;
     struct icalreqstattype stat;
     short major = 0, minor = 0;
 
@@ -112,16 +112,6 @@ struct icalreqstattype icalreqstattype_from_string(const char *str)
     stat.debug = 0;
     stat.desc = 0;
 
-    // Don't allow (fuzzer) garbage chars anywhere in the reqstat string
-    s = str;
-    while (*s && isprint((unsigned char)*s)) {
-        ++s;
-    }
-    if (*s != '\0') {
-        // garbage encountered. return the empty stat
-        return stat;
-    }
-
     /* Get the status numbers */
 
     sscanf(str, "%hd.%hd", &major, &minor);
@@ -149,7 +139,7 @@ struct icalreqstattype icalreqstattype_from_string(const char *str)
      */
 
     p2 = strchr(p1 + 1, ';');
-    if (p2 != 0 && *(p2 + 1) != 0) { // skipping empty debug strings
+    if (p2 != 0 && *p2 != 0) {
         stat.debug = icalmemory_tmp_copy(p2 + 1);
     }
 
@@ -180,6 +170,7 @@ char *icalreqstattype_as_string_r(struct icalreqstattype stat)
     if (stat.debug != 0) {
         snprintf(temp, TMP_BUF_SIZE, "%d.%d;%s;%s", icalenum_reqstat_major(stat.code),
                  icalenum_reqstat_minor(stat.code), stat.desc, stat.debug);
+
     } else {
         snprintf(temp, TMP_BUF_SIZE, "%d.%d;%s", icalenum_reqstat_major(stat.code),
                  icalenum_reqstat_minor(stat.code), stat.desc);
