@@ -2,18 +2,19 @@
  FILE: icalvalue.c
  CREATOR: eric 02 May 1999
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 
   Contributions from:
      Graham Davison <g.m.davison@computer.org>
@@ -303,16 +304,13 @@ static char *icalmemory_strdup_and_quote(const icalvalue *value, const char *unq
         case ',':
             /* unescaped COMMA is allowed in CATEGORIES property as its
                considered a list delimiter here, see:
-               https://tools.ietf.org/html/rfc5545#section-3.8.1.2 */
+               http://tools.ietf.org/html/rfc5545#section-3.8.1.2 */
             if ((icalproperty_isa(value->parent) == ICAL_CATEGORIES_PROPERTY) ||
                 (icalproperty_isa(value->parent) == ICAL_RESOURCES_PROPERTY) ||
-                (icalproperty_isa(value->parent) == ICAL_POLLPROPERTIES_PROPERTY) ||
-                ((icalproperty_isa(value->parent) == ICAL_X_PROPERTY) &&
-                 icalvalue_isa(value) != ICAL_TEXT_VALUE)) {
+                (icalproperty_isa(value->parent) == ICAL_POLLPROPERTIES_PROPERTY)) {
                 icalmemory_append_char(&str, &str_p, &buf_sz, *p);
                 break;
             }
-            /* falls through */
 /*issue74, we don't escape double quotes
         case '"':
 */
@@ -366,8 +364,8 @@ static icalvalue *icalvalue_new_enum(icalvalue_kind kind, int x_type, const char
  * The decimal separator (if any) of the double has to be '.'
  * The code is locale *independent* and does *not* change the locale.
  * It should be thread safe.
- * If you want a code that does the same job with a decimal separator
- * dependent on the current locale, then use strtof() from libc.
+ * If you want a code that that does the same job with a decimal separator
+ * dependant on the current locale, then use strtof() from libc.
  */
 static int simple_str_to_double(const char *from, double *result, char **to)
 {
@@ -386,16 +384,17 @@ static int simple_str_to_double(const char *from, double *result, char **to)
     }
 
     /*skip the white spaces at the beginning */
-    while (*cur && isspace((int)*cur))
+    while (cur && isspace((int)*cur))
         cur++;
 
     start = cur;
-    /* copy the part that looks like a double into tmp_buf
+    /*
+     * copy the part that looks like a double into tmp_buf
      * so that we can call strtof() on it.
      * during the copy, we give ourselves a chance to convert the '.'
      * into the decimal separator of the current locale.
      */
-    while (*cur && (isdigit((int)*cur) || *cur == '.' || *cur == '+' || *cur == '-')) {
+    while (cur && (isdigit((int)*cur) || *cur == '.' || *cur == '+' || *cur == '-')) {
         ++cur;
     }
     end = cur;
@@ -405,7 +404,8 @@ static int simple_str_to_double(const char *from, double *result, char **to)
     }
     memset(tmp_buf, 0, TMP_NUM_SIZE + 1);
 
-    /* copy the float number string into tmp_buf, and take
+    /*
+     * copy the float number string into tmp_buf, and take
      * care to have the (optional) decimal separator be the one
      * of the current locale.
      */
@@ -429,12 +429,6 @@ static int simple_str_to_double(const char *from, double *result, char **to)
     return 0;
 }
 
-static void free_icalvalue_attach_data(char *data, void *user_data)
-{
-    _unused(user_data);
-    free(data);
-}
-
 static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
                                                        const char *str, icalproperty ** error)
 {
@@ -465,7 +459,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
         {
             icalattach *attach;
 
-            attach = icalattach_new_from_data(strdup(str), free_icalvalue_attach_data, 0);
+            attach = icalattach_new_from_data(str, NULL, 0);
             if (!attach)
               break;
 
@@ -487,7 +481,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
                          "Could not parse %s as a %s property",
                          str, icalvalue_kind_to_string(kind));
                 errParam = icalparameter_new_xlicerrortype(ICAL_XLICERRORTYPE_VALUEPARSEERROR);
-                *error = icalproperty_vanew_xlicerror(temp, errParam, (void *)0);
+                *error = icalproperty_vanew_xlicerror(temp, errParam, 0);
                 icalparameter_free(errParam);
             }
             break;
@@ -544,7 +538,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
         {
             int t, utcoffset, hours, minutes, seconds;
 
-            /* treat the UTCOFSET string as a decimal number, disassemble its digits
+            /* treat the UTCOFSET string a a decimal number, disassemble its digits
                and reconstruct it as sections */
             t = strtol(str, 0, 10);
             /* add phantom seconds field */
@@ -623,7 +617,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
                          "Could not parse %s as a %s property",
                          str, icalvalue_kind_to_string(kind));
                 errParam = icalparameter_new_xlicerrortype(ICAL_XLICERRORTYPE_VALUEPARSEERROR);
-                *error = icalproperty_vanew_xlicerror(temp, errParam, (void *)0);
+                *error = icalproperty_vanew_xlicerror(temp, errParam, 0);
                 icalparameter_free(errParam);
             }
         }
@@ -738,7 +732,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
                 snprintf(temp, TMP_BUF_SIZE, "Unknown type for \'%s\'", str);
 
                 errParam = icalparameter_new_xlicerrortype(ICAL_XLICERRORTYPE_VALUEPARSEERROR);
-                *error = icalproperty_vanew_xlicerror(temp, errParam, (void *)0);
+                *error = icalproperty_vanew_xlicerror(temp, errParam, 0);
                 icalparameter_free(errParam);
             }
 
@@ -757,7 +751,7 @@ static icalvalue *icalvalue_new_from_string_with_error(icalvalue_kind kind,
         snprintf(temp, TMP_BUF_SIZE, "Failed to parse value: \'%s\'", str);
 
         errParam = icalparameter_new_xlicerrortype(ICAL_XLICERRORTYPE_VALUEPARSEERROR);
-        *error = icalproperty_vanew_xlicerror(temp, errParam, (void *)0);
+        *error = icalproperty_vanew_xlicerror(temp, errParam, 0);
         icalparameter_free(errParam);
     }
 
@@ -901,13 +895,10 @@ static char *icalvalue_utcoffset_as_ical_string_r(const icalvalue *value)
     m = (data - (h * 3600)) / 60;
     s = (data - (h * 3600) - (m * 60));
 
-    h = MIN(abs(h), 23);
-    m = MIN(abs(m), 59);
-    s = MIN(abs(s), 59);
     if (s != 0) {
-        snprintf(str, 9, "%c%02d%02d%02d", sign, h, m, s);
+        snprintf(str, 9, "%c%02d%02d%02d", sign, abs(h), abs(m), abs(s));
     } else {
-        snprintf(str, 9, "%c%02d%02d", sign, h, m);
+        snprintf(str, 9, "%c%02d%02d", sign, abs(h), abs(m));
     }
 
     return str;
@@ -980,13 +971,10 @@ static void print_time_to_string(char *str, const struct icaltimetype *data)
 {       /* this function is a candidate for a library-wide external function
            except it isn't used any place outside of icalvalue.c.
            see print_date_to_string() and print_datetime_to_string in icalvalue.h */
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wstringop-truncation"
-#endif
-    char temp[8];
+    char temp[20];
 
     str[0] = '\0';
+
     if (data != 0) {
         if (icaltime_is_utc(*data)) {
             snprintf(temp, sizeof(temp), "%02d%02d%02dZ", data->hour, data->minute, data->second);
@@ -996,18 +984,11 @@ static void print_time_to_string(char *str, const struct icaltimetype *data)
             strncat(str, temp, 6);
         }
     }
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic pop
-#endif
 }
 
 void print_date_to_string(char *str, const struct icaltimetype *data)
 {
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wstringop-truncation"
-#endif
-    char temp[9];
+    char temp[20];
 
     str[0] = '\0';
 
@@ -1015,9 +996,6 @@ void print_date_to_string(char *str, const struct icaltimetype *data)
         snprintf(temp, sizeof(temp), "%04d%02d%02d", data->year, data->month, data->day);
         strncat(str, temp, 8);
     }
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic pop
-#endif
 }
 
 static char *icalvalue_date_as_ical_string_r(const icalvalue *value)
@@ -1038,13 +1016,10 @@ static char *icalvalue_date_as_ical_string_r(const icalvalue *value)
 
 void print_datetime_to_string(char *str, const struct icaltimetype *data)
 {
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wstringop-truncation"
-#endif
     char temp[20];
 
     str[0] = '\0';
+
     if (data != 0) {
         print_date_to_string(str, data);
         if (!data->is_date) {
@@ -1054,9 +1029,6 @@ void print_datetime_to_string(char *str, const struct icaltimetype *data)
             strncat(str, temp, 19);
         }
     }
-#if defined(__GNUC__) && !defined(__clang__)
-#pragma GCC diagnostic pop
-#endif
 }
 
 static char *icalvalue_datetime_as_ical_string_r(const icalvalue *value)
@@ -1540,8 +1512,8 @@ int icalvalue_decode_ical_string(const char *szText, char *szDecText, int nMaxBu
     if ((szText == 0) || (szDecText == 0))
         return 0;
 
-    buf_sz = strlen(szText) + 1;
-    str_p = str = (char *)icalmemory_new_buffer(buf_sz);
+    buf_sz = strlen(szText);
+    str_p = str = (char *)icalmemory_new_buffer(buf_sz + 1);
 
     if (str_p == 0) {
         return 0;
@@ -1554,14 +1526,11 @@ int icalvalue_decode_ical_string(const char *szText, char *szDecText, int nMaxBu
         } else {
             icalmemory_append_char(&str, &str_p, &buf_sz, *p);
         }
-
-        if (str_p - str > nMaxBufferLen)
-            break;
     }
 
     icalmemory_append_char(&str, &str_p, &buf_sz, '\0');
 
-    if ((int)strlen(str) >= nMaxBufferLen) {
+    if ((int)strlen(str) > nMaxBufferLen) {
         icalmemory_free_buffer(str);
         return 0;
     }
