@@ -7,12 +7,12 @@
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 ======================================================================*/
 
 #ifdef HAVE_CONFIG_H
@@ -31,16 +31,8 @@
 
 #define MAX_RETRY 5
 
-#if !defined(DB_VERSION_MAJOR)
-#define DB_VERSION_MAJOR 1 //assume ancient version
-#endif
-
 static int _compare_ids(const char *compid, const char *matchid);
-#if DB_VERSION_MAJOR > 5
-static int _compare_keys(DB *dbp, const DBT *a, const DBT *b, size_t *locp);
-#else
 static int _compare_keys(DB *dbp, const DBT *a, const DBT *b);
-#endif
 
 /** Default options used when NULL is passed to icalset_new() **/
 static icalbdbset_options icalbdbset_options_default =
@@ -83,11 +75,7 @@ int icalbdbset_init_dbenv(char *db_env_dir,
 
     flags = (u_int32_t) (DB_INIT_LOCK | DB_INIT_TXN | DB_CREATE | DB_THREAD |
                          DB_RECOVER | DB_INIT_LOG | DB_INIT_MPOOL);
-#if defined(_WIN32) //krazy:exclude=cpp
-    ret = ICAL_DB_ENV->open(ICAL_DB_ENV, db_env_dir, flags, 0 /*ignored on Windows*/);
-#else
     ret = ICAL_DB_ENV->open(ICAL_DB_ENV, db_env_dir, flags, S_IRUSR | S_IWUSR);
-#endif
 
     if (ret) {
         /*char *foo = db_strerror(ret); */
@@ -120,9 +108,9 @@ void icalbdbset_rmdbLog(void)
 {
     char **listp;
 
-    /* remove log files that are can be archived (ie. no longer needed) */
+    /* remove log files that are archivable (ie. no longer needed) */
     if (ICAL_DB_ENV->log_archive(ICAL_DB_ENV, &listp, DB_ARCH_ABS) == 0) {
-        if (*listp != NULL) {
+        if (listp != NULL) {
             int ii = 0;
 
             while (listp[ii] != NULL) {
@@ -193,7 +181,8 @@ static icalerrorenum icalbdbset_read_database(icalbdbset *bset, char *(*pfunc) (
 
     bset->cluster = icalcomponent_new(ICAL_XROOT_COMPONENT);
 
-    if (ICAL_DB_ENV->txn_begin(ICAL_DB_ENV, NULL, &tid, 0) != 0) {
+    if ((ret = ICAL_DB_ENV->txn_begin(ICAL_DB_ENV, NULL, &tid, 0)) != 0) {
+        /*char *foo = db_strerror(ret); */
         abort();
     }
 
@@ -255,11 +244,13 @@ static icalerrorenum icalbdbset_read_database(icalbdbset *bset, char *(*pfunc) (
         more_mem = NULL;
     }
 
-    if (dbcp->c_close(dbcp) != 0) {
+    if ((ret = dbcp->c_close(dbcp)) != 0) {
+        /*char *foo = db_strerror(ret); */
         abort();        /* should retry in case of DB_LOCK_DEADLOCK */
     }
 
-    if (tid->commit(tid, 0) != 0) {
+    if ((ret = tid->commit(tid, 0)) != 0) {
+        /*char *foo = db_strerror(ret); */
         abort();
     }
 
@@ -283,6 +274,7 @@ icalset *icalbdbset_init(icalset *set, const char *dsn, void *options_in)
 {
     icalbdbset *bset = (icalbdbset *) set;
     icalbdbset_options *options = (icalbdbset_options *) options_in;
+    int ret;
     DB *cal_db;
     const char *subdb_name = NULL;
 
@@ -318,7 +310,7 @@ icalset *icalbdbset_init(icalset *set, const char *dsn, void *options_in)
     bset->gauge = 0;
     bset->cluster = 0;
 
-    if (icalbdbset_read_database(bset, options->pfunc) != ICAL_NO_ERROR) {
+    if ((ret = icalbdbset_read_database(bset, options->pfunc)) != ICAL_NO_ERROR) {
         return NULL;
     }
 
@@ -416,7 +408,7 @@ DB *icalbdbset_bdb_open(const char *path, const char *subdb, int dbtype, int mod
     }
 
     /* Create and initialize database object, open the database. */
-    if (db_create(&dbp, ICAL_DB_ENV, 0) != 0) {
+    if ((ret = db_create(&dbp, ICAL_DB_ENV, 0)) != 0) {
         return NULL;
     }
 
@@ -460,6 +452,7 @@ char *icalbdbset_parse_data(DBT *dbt, char *(*pfunc) (const DBT *dbt))
 void icalbdbset_free(icalset *set)
 {
     icalbdbset *bset = (icalbdbset *) set;
+    int ret;
 
     icalerror_check_arg_rv((bset != 0), "bset");
 
@@ -483,8 +476,7 @@ void icalbdbset_free(icalset *set)
         bset->sindex = 0;
     }
 
-    if (bset->dbp && (bset->dbp->close(bset->dbp, 0) != 0)) {
-        /* ?? */
+    if (bset->dbp && ((ret = bset->dbp->close(bset->dbp, 0)) != 0)) {
     }
     bset->dbp = NULL;
 }
@@ -529,7 +521,7 @@ int icalbdbset_get_key(DBC *dbcp, DBT *key, DBT *data)
 int icalbdbset_delete(DB *dbp, DBT *key)
 {
     DB_TXN *tid;
-    int ret = 0;
+    int ret;
     int done = 0;
     int retry = 0;
 
@@ -555,7 +547,7 @@ int icalbdbset_delete(DB *dbp, DBT *key)
             } else {
                 char *strError = db_strerror(ret);
 
-                icalerror_warn("icalbdbset_delete failed: ");
+                icalerror_warn("icalbdbset_delete faild: ");
                 icalerror_warn(strError);
                 tid->abort(tid);
                 return ICAL_FILE_ERROR;
@@ -587,11 +579,13 @@ int icalbdbset_delete(DB *dbp, DBT *key)
 
 int icalbdbset_cget(DBC *dbcp, DBT *key, DBT *data, u_int32_t access_method)
 {
+    int ret = 0;
+
     key->flags |= DB_DBT_MALLOC;        /* change these to DB_DBT_USERMEM */
     data->flags |= DB_DBT_MALLOC;
 
     /* fetch the key/data pair */
-    if (dbcp->c_get(dbcp, key, data, access_method) != 0) {
+    if ((ret = dbcp->c_get(dbcp, key, data, access_method)) != 0) {
         goto err1;
     }
 
@@ -603,13 +597,15 @@ int icalbdbset_cget(DBC *dbcp, DBT *key, DBT *data, u_int32_t access_method)
 
 int icalbdbset_cput(DBC *dbcp, DBT *key, DBT *data, u_int32_t access_method)
 {
+    int ret = 0;
+
     _unused(access_method);
 
     key->flags |= DB_DBT_MALLOC;        /* change these to DB_DBT_USERMEM */
     data->flags |= DB_DBT_MALLOC;
 
     /* fetch the key/data pair */
-    if (dbcp->c_put(dbcp, key, data, 0) != 0) {
+    if ((ret = dbcp->c_put(dbcp, key, data, 0)) != 0) {
         goto err1;
     }
 
@@ -646,7 +642,7 @@ int icalbdbset_put(DB *dbp, DBT *key, DBT *data, u_int32_t access_method)
             } else {
                 char *strError = db_strerror(ret);
 
-                icalerror_warn("icalbdbset_put failed: ");
+                icalerror_warn("icalbdbset_put faild: ");
                 icalerror_warn(strError);
                 tid->abort(tid);
                 return ICAL_FILE_ERROR;
@@ -682,7 +678,7 @@ int icalbdbset_get(DB *dbp, DB_TXN *tid, DBT *key, DBT *data, u_int32_t flags)
     return dbp->get(dbp, tid, key, data, flags);
 }
 
-/** Returns the path of the database file **/
+/** Return the path of the database file **/
 
 const char *icalbdbset_path(icalset *set)
 {
@@ -883,6 +879,10 @@ icalerrorenum icalbdbset_commit(icalset *set)
             }
         }
 
+        if (str) {
+            free(str);
+        }
+
         if (deadlocked) {
             dbcp->c_close(dbcp);
             tid->abort(tid);
@@ -986,7 +986,7 @@ int icalbdbset_count_components(icalset *set, icalcomponent_kind kind)
     return icalcomponent_count_components(bset->cluster, kind);
 }
 
-/** Sets the gauge **/
+/** Set the gauge **/
 
 icalerrorenum icalbdbset_select(icalset *set, icalgauge *gauge)
 {
@@ -1275,7 +1275,7 @@ icalsetiter icalbdbset_begin_component(icalset *set, icalcomponent_kind kind,
     /* if there is a gauge, the first matched component is returned */
     while (comp != 0) {
 
-        /* check if it is a recurring component and with gauge expand, if so
+        /* check if it is a recurring component and with guage expand, if so
          * we need to add recurrence-id property to the given component */
         rrule = icalcomponent_get_first_property(comp, ICAL_RRULE_PROPERTY);
         g = icalgauge_get_expand(gauge);
@@ -1610,11 +1610,7 @@ int icalbdbset_commit_transaction(DB_TXN *txnid)
     return txnid->commit(txnid, 0);
 }
 
-#if DB_VERSION_MAJOR > 5
-static int _compare_keys(DB *dbp, const DBT *a, const DBT *b, size_t *locp)
-#else
 static int _compare_keys(DB *dbp, const DBT *a, const DBT *b)
-#endif
 {
     /*
      * Returns:
@@ -1627,8 +1623,5 @@ static int _compare_keys(DB *dbp, const DBT *a, const DBT *b)
     char *bc = (char *)b->data;
 
     _unused(dbp);
-#if DB_VERSION_MAJOR > 5
-    locp = NULL;
-#endif
     return strncmp(ac, bc, a->size);
 }
