@@ -4,15 +4,15 @@
 
  (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
 
- This program is free software; you can redistribute it and/or modify
+ This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
     2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
-  Or:
+ Or:
 
-    The Mozilla Public License Version 1.0. You may obtain a copy of
+    The Mozilla Public License Version 2.0. You may obtain a copy of
     the License at http://www.mozilla.org/MPL/
  =========================================================================*/
 
@@ -41,17 +41,6 @@ LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_delegate_reply(icalcomponen
                                                                     const char *delegatee,
                                                                     const char *msg);
 
-LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_cancel_event(icalcomponent *c,
-                                                                  const char *user,
-                                                                  const char *msg);
-
-LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_cancel_instance(icalcomponent *c,
-                                                                     const char *user,
-                                                                     const char *msg);
-
-LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_cancel_all(icalcomponent *c,
-                                                                const char *user, const char *msg);
-
 LIBICAL_ICALSS_EXPORT icalcomponent *icalmessage_new_error_reply(icalcomponent *c,
                                                                  const char *user,
                                                                  const char *msg,
