@@ -2,23 +2,23 @@
  FILE: icalvcal.c
  CREATOR: eric 25 May 00
 
- (C) COPYRIGHT 2000, Eric Busboom <eric@civicknowledge.com>
+ (C) COPYRIGHT 2000, Eric Busboom <eric@softwarestudio.org>
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 
  The original code is icalvcal.c
 
  The icalvcal_convert routine calls icalvcal_traverse_objects to do
- its work.s his routine steps through all of the properties
+ its work.s his routine steps through through all of the properties
  and components of a VObject. For each name of a property or a
  component, icalvcal_traverse_objects looks up the name in
  conversion_table[]. This table indicates whether the name is of a
@@ -55,9 +55,9 @@ enum datatype
 };
 
 /* The indices must match between the strings and the codes. */
-static const char weekdays[][3] = { "SU", "MO", "TU", "WE", "TH", "FR", "SA" };
+static const char *weekdays[] = { "SU", "MO", "TU", "WE", "TH", "FR", "SA" };
 
-static const int weekday_codes[] = {
+static int weekday_codes[] = {
     ICAL_SUNDAY_WEEKDAY,
     ICAL_MONDAY_WEEKDAY,
     ICAL_TUESDAY_WEEKDAY,
@@ -902,7 +902,7 @@ static const char *rrule_parse_weekly_days(const char *s,
         if (found_day == -1)
             break;
 
-        /* cppcheck-suppress arrayIndexOutOfBounds; since 'day' can't be >6 */
+        /* cppcheck-suppress arrayIndexOutOfBounds since 'day' can't be >6 */
         recur->by_day[i] = weekday_codes[day];
 
         s = e;
@@ -1258,7 +1258,7 @@ static void *rule_prop(int icaltype, VObject *object, icalcomponent *comp,
     return (void *)prop;
 }
 
-/* directly convertible property. The string representation of vcal is
+/* directly convertable property. The string representation of vcal is
    the same as ical */
 
 void *dc_prop(int icaltype, VObject *object, icalcomponent *comp, icalvcal_defaults *defaults)
@@ -1481,7 +1481,7 @@ static void icalvcal_traverse_objects(VObject *object,
                                       icalproperty *last_prop, icalvcal_defaults *defaults)
 {
     VObjectIterator iterator;
-    const char *name;
+    const char *name = "[No Name]";
     icalcomponent *subc = 0;
     int i;
 
