@@ -344,7 +344,7 @@ class GenericComponent(Component):
 
         # Get the value
         if value==None:
-            if not curr_properties:
+            if len(curr_properties) == 0:
                 return None
             elif len(curr_properties) == 1:
                 return curr_properties[0]
@@ -383,7 +383,7 @@ class GenericComponent(Component):
 
             if len(curr_properties) == 1:
                 comp.remove_property(curr_properties[0])
-            elif curr_properties:
+            elif len(curr_properties) > 1:
                 raise ValueError, "too many properties of type %s" % propType
 
             comp.add_property(p)
@@ -615,7 +615,7 @@ class GenericComponent(Component):
         Examples:
         # Set using string[s]
         categories(('APPOINTMENT', 'EDUCATION'))
-        # Returns a list of Category properties
+        # Returns a list of Category properites
         categories()
 
         When setting the attendees, any previous category Properties in the
@@ -793,7 +793,7 @@ class Todo(GenericComponent):
 
     def duration(self, value=None):
         if value != None:
-            due = self.properties('DUE')
+            due = self.properites('DUE')
             for d in due:
                 self.remove_property(d)  # Clear DUE properties
         return self._singular_property("DURATION", "DURATION", value, Duration)
