@@ -2,18 +2,19 @@
  FILE: icalrecur_test.c
  CREATOR: Ken Murchison 26 September 2014
 
- (C) COPYRIGHT 2000 Eric Busboom <eric@civicknowledge.com>
+ (C) COPYRIGHT 2000 Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 ======================================================================*/
 
 /*
@@ -363,12 +364,6 @@ const struct recur rfc5545[] = {
      "FREQ=WEEKLY;UNTIL=20170127T000000Z;WKST=MO;BYDAY=SU,TU,TH;INTERVAL=2",
      "20161231T090000"},
 
-    /* Bi-weekly on Sunday, Tuesday, and Thursday until January 27, 2017,
-       starting second day of 2017 */
-    {"20161229T090000",
-     "FREQ=WEEKLY;UNTIL=20170127T000000Z;WKST=MO;BYDAY=SU,TU,TH;INTERVAL=2",
-     "20170102T090000"},
-
     /* Every 3rd day in January, starting on the 10th */
     {"20170101T090000",
      "FREQ=DAILY;UNTIL=20170131T140000Z;BYMONTH=1;INTERVAL=3",
@@ -380,31 +375,6 @@ const struct recur rfc5545[] = {
      "FREQ=HOURLY;INTERVAL=3;UNTIL=20170903T170000Z",
      "20170902T230000"},
 
-    /* Every 13 months, on May 12 */
-    {"20100212T000000",
-     "FREQ=MONTHLY;INTERVAL=13;BYMONTH=5;COUNT=3",
-     NULL},
-
-    /* github issue376 */
-    {"20190101T100000",
-     "FREQ=WEEKLY;BYDAY=WE,FR;INTERVAL=2;COUNT=4",
-     NULL},
-
-    /* First 2 and last 2 ISO weeks of the year on Tue */
-    {"20130101T000000",
-     "FREQ=YEARLY;BYWEEKNO=1,2,-1,-2;BYDAY=TU;UNTIL=20170101T000000Z",
-     NULL},
-
-    /* 53rd ISO week of the year on Tue and Sat */
-    {"20130101T000000",
-     "FREQ=YEARLY;BYWEEKNO=53;BYDAY=TU,SA;UNTIL=20170101T000000Z",
-     NULL},
-
-    /* github issue491 */
-    {"20210301T142000",
-     "FREQ=HOURLY;UNTIL=20210303T000000Z",
-     "20210302T100000"},
-
     {NULL, NULL, NULL}
 };
 
@@ -415,7 +385,6 @@ const struct recur rscale[] = {
      "RSCALE=RUSSIAN;FREQ=YEARLY",
      NULL},
 
-#if defined(HAVE_LIBICU)
     /* Ethiopic last day of year */
     {"20140910",
      "RSCALE=ETHIOPIC;FREQ=YEARLY;BYMONTH=13;BYMONTHDAY=-1;COUNT=6",
@@ -475,11 +444,6 @@ const struct recur rscale[] = {
      "RSCALE=CHINESE;FREQ=YEARLY;BYMONTHDAY=10;BYMONTH=9,9L;SKIP=BACKWARD;COUNT=4",
      NULL},
 
-    /* Every other Chinese New Year, starting at Jan 1, 2016 */
-    {"20130210",
-     "RSCALE=CHINESE;FREQ=YEARLY;UNTIL=20200101;INTERVAL=2",
-     "20160101"},
-
     /* Jewish leap month (omit) */
     {"20140205",
      "RSCALE=HEBREW;FREQ=YEARLY;COUNT=4",
@@ -514,7 +478,6 @@ const struct recur rscale[] = {
     {"20140302",
      "RSCALE=HEBREW;FREQ=YEARLY;BYMONTH=5L;BYMONTHDAY=-1;SKIP=BACKWARD;COUNT=5",
      NULL},
-#endif /* HAVE_LIBICU */
 
     /* Gregorian leap day (omit) */
     {"20120229",
@@ -581,15 +544,21 @@ const struct recur rscale[] = {
      "RSCALE=GREGORIAN;FREQ=YEARLY;BYYEARDAY=-366;SKIP=BACKWARD;COUNT=9",
      NULL},
 
+    /* Every other Chinese New Year, starting at Jan 1, 2016 */
+    {"20130210",
+     "RSCALE=CHINESE;FREQ=YEARLY;UNTIL=20200101;INTERVAL=2",
+     "20160101"},
+
     {NULL, NULL, NULL}
 };
 
 int main(int argc, char *argv[])
 {
+    int opt;
+
     /* Default to RFC 5545 tests */
     const struct recur *r = rfc5545;
     FILE *fp = fopen("test.out", "w");
-    int i;
     int verbose = 0;
 
     if (fp == NULL) {
@@ -597,21 +566,29 @@ int main(int argc, char *argv[])
         return (1);
     }
 
-    /* Do not use getopt for command line parsing -- for portability on Windows */
-    for (i = 1; i < argc; ++i) {
-        if (strncmp(argv[i], "-r", 2) == 0) { /* Do RSCALE tests */
+    while ((opt = getopt(argc, argv, "rv")) != EOF) {
+        switch (opt) {
+#if defined(HAVE_LIBICU)
+        case 'r':      /* Do RSCALE tests */
+            if (!icalrecurrencetype_rscale_is_supported()) {
+                fprintf(stderr, "error: RSCALE not supported\n");
+                fclose(fp);
+                return (1);
+            }
             r = rscale;
-            continue;
-        }
+            break;
+#endif
 
-        if (strncmp(argv[i], "-v", 2) == 0) { /* Verbose output to stdout */
+        case 'v':      /* Verbose output to stdout */
             verbose = 1;
-            continue;
-        }
+            break;
 
-        fprintf(stderr, "usage: %s [-r]\n", argv[0]);
-        fclose(fp);
-        return (1);
+        default:
+            fprintf(stderr, "usage: %s [-r]\n", argv[0]);
+            fclose(fp);
+            return (1);
+            break;
+        }
     }
 
     for (; r->dtstart; r++) {
