@@ -2,18 +2,19 @@
  FILE: process.c
  CREATOR: eric 11 February 2000
 
- (C) COPYRIGHT 2000 Eric Busboom <eric@civicknowledge.com>
+ (C) COPYRIGHT 2000 Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 ======================================================================*/
 
 #ifdef HAVE_CONFIG_H
@@ -31,6 +32,7 @@ void send_message(icalcomponent *reply, const char *this_user)
 int main(int argc, char *argv[])
 {
     icalcomponent *c, *next_c = NULL;
+    int i = 0;
     int dont_remove;
     icalfileset_options options = { O_RDONLY, 0644, 0, NULL };
 
@@ -61,6 +63,7 @@ int main(int argc, char *argv[])
 
         inner = icalcomponent_get_first_real_component(c);
 
+        i++;
         reply = 0;
         dont_remove = 0;
 
