@@ -1,18 +1,19 @@
 /*======================================================================
  FILE: regression-component.c
 
- (C) COPYRIGHT 1999 Eric Busboom <eric@civicknowledge.com>
+ (C) COPYRIGHT 1999 Eric Busboom <eric@softwarestudio.org>
+     http://www.softwarestudio.org
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 
  The original author is Eric Busboom
 ======================================================================*/
@@ -97,7 +98,6 @@ void create_new_component()
     rtime.period.start = icaltime_from_timet_with_zone(1023398689, 0, NULL);
     rtime.period.end = icaltime_from_timet_with_zone(1023409689, 0, NULL);
     rtime.period.end.hour++;
-    rtime.period.duration = icaldurationtype_null_duration();
     rtime.time = icaltime_null_time();
 
     /* Create calendar and add properties */
@@ -222,7 +222,6 @@ void create_new_component_with_va_args()
     rtime.period.start = icaltime_from_timet_with_zone(time(0), 0, NULL);
     rtime.period.end = icaltime_from_timet_with_zone(time(0), 0, NULL);
     rtime.period.end.hour++;
-    rtime.period.duration = icaldurationtype_null_duration();
     rtime.time = icaltime_null_time();
 
     calendar =
@@ -448,7 +447,7 @@ void test_icalcomponent_get_span()
     if (VERBOSE)
         print_span(tnum++, span);
 
-    int_is("start == end", (int)span.start, span.end);
+    int_is("null span", (int)span.start, 0);
     icalcomponent_free(c);
 
     /** test 7
