@@ -7,15 +7,16 @@
 
  DESCRIPTION:
 
- The contents of this file are subject to the Mozilla Public License
- Version 1.0 (the "License"); you may not use this file except in
- compliance with the License. You may obtain a copy of the License at
- http://www.mozilla.org/MPL/
+ This library is free software; you can redistribute it and/or modify
+ it under the terms of either:
 
- Software distributed under the License is distributed on an "AS IS"
- basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
- the License for the specific language governing rights and
- limitations under the License.
+    The LGPL as published by the Free Software Foundation, version
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+
+ Or:
+
+    The Mozilla Public License Version 2.0. You may obtain a copy of
+    the License at http://www.mozilla.org/MPL/
 
  The original author is Eric Busboom
  The original code is usecases.c
@@ -55,9 +56,9 @@ struct calendar
 
 };
 
-int vcalendar_init(struct calendar **cal, char *vcalendar, char *title);
+int vcalendar_init(struct calendar **cal, const char *vcalendar, const char *title);
 
-#if defined(WITH_BDB)
+#if defined(HAVE_BDB)
 #include <db.h>
 
 int get_title(DB *dbp, const DBT *pkey, const DBT *pdata, DBT *skey);
@@ -140,7 +141,7 @@ void test_fileset_extended(void)
     icalcomponent *c, *clone, *itr;
     icalsetiter iter;
 
-    start = icaltime_from_timet(time(0), 0);
+    start = icaltime_from_timet_with_zone(time(0), 0, NULL);
     end = start;
     end.hour++;
 
@@ -191,6 +192,7 @@ void test_fileset_extended(void)
         (void)icalfileset_add_component(cout, clone);
         (void)icalfileset_commit(cout);
 
+        icalcomponent_free(clone);
         icalset_free(cout);
     }
 
@@ -271,7 +273,7 @@ void test_fileset_extended(void)
     icalcomponent_free(c);
 }
 
-#if defined(WITH_BDB)
+#if defined(HAVE_BDB)
 
 /*
    In this example, we're storing a calendar with several components
@@ -304,7 +306,7 @@ void test_bdbset()
 
     return;     // for now... TODO fix these broken tests..
 
-    start = icaltime_from_timet(time(0), 0);
+    start = icaltime_from_timet_with_zone(time(0), 0, NULL);
     end = start;
     end.hour++;
 
@@ -455,7 +457,7 @@ void test_bdbset()
 
 #endif
 
-int vcalendar_init(struct calendar **rcal, char *vcalendar, char *title)
+int vcalendar_init(struct calendar **rcal, const char *vcalendar, const char *title)
 {
     size_t vcalendar_size, title_size, total_size;
     struct calendar *cal;
@@ -493,10 +495,10 @@ int vcalendar_init(struct calendar **rcal, char *vcalendar, char *title)
     cal->vcalendar_size = vcalendar_size;
     cal->title_size = title_size;
 
-    if (vcalendar && *vcalendar)
+    if (*vcalendar) /* we know that vcalendar is not NULL here */
         cal->vcalendar = strdup(vcalendar);
 
-    if (title && *title)
+    if (*title) /* we know that title is not NULL here */
         cal->title = strdup(title);
 
     *rcal = cal;
@@ -508,7 +510,7 @@ int vcalendar_init(struct calendar **rcal, char *vcalendar, char *title)
  * from a primary key/data pair */
 
 /* just create a random title for now */
-#if defined(WITH_BDB)
+#if defined(HAVE_BDB)
 
 int get_title(DB *dbp, const DBT *pkey, const DBT *pdata, DBT *skey)
 {
@@ -579,8 +581,10 @@ struct calendar *unpack_calendar(char *str, size_t size)
     /* vcalendar_size */
     memcpy(&cal->vcalendar_size, str + cal->vcalendar_size_offset, sizeof(cal->vcalendar_size));
 
-    if ((cal->vcalendar = (char *)malloc(sizeof(char) * cal->vcalendar_size)) == NULL)
+    if ((cal->vcalendar = (char *)malloc(sizeof(char) * cal->vcalendar_size)) == NULL) {
+        free(cal);
         return 0;
+    }
 
     /* vcalendar */
     memcpy(cal->vcalendar, (char *)(str + cal->vcalendar_offset), cal->vcalendar_size);
@@ -591,8 +595,11 @@ struct calendar *unpack_calendar(char *str, size_t size)
     /* title_size */
     memcpy(&cal->title_size, str + cal->title_size_offset, sizeof(cal->title_size));
 
-    if ((cal->title = (char *)malloc(sizeof(char) * cal->title_size)) == NULL)
+    if ((cal->title = (char *)malloc(sizeof(char) * cal->title_size)) == NULL) {
+        free(cal->vcalendar);
+        free(cal);
         return 0;
+    }
 
     /* title */
     memcpy(cal->title, (char *)(str + cal->title_offset), cal->title_size);
@@ -608,7 +615,9 @@ char *parse_vcalendar(const DBT *dbt)
     str = (char *)dbt->data;
     cal = unpack_calendar(str, dbt->size);
 
-    return cal->vcalendar;
+    str = cal->vcalendar;
+    free(cal);
+    return str;
 }
 
 #endif
@@ -628,7 +637,7 @@ void test_dirset_extended(void)
     ok("Open dirset 'store'", (s != 0));
     assert(s != 0);
 
-    rtime.start = icaltime_from_timet(time(0), 0);
+    rtime.start = icaltime_from_timet_with_zone(time(0), 0, NULL);
 
     cluster = icalfileset_new(OUTPUT_FILE);
 
@@ -723,15 +732,11 @@ void test_dirset_extended(void)
 
         printf("Got one! (%d)\n", count++);
 
-        if (c != 0) {
-            printf("%s", icalcomponent_as_ical_string(c));
-            if (icaldirset_add_component(s2, c) == 0) {
-                printf("Failed to write!\n");
-            }
-            icalcomponent_free(c);
-        } else {
-            printf("Failed to get component\n");
+        printf("%s", icalcomponent_as_ical_string(c));
+        if (icaldirset_add_component(s2, c) == 0) {
+            printf("Failed to write!\n");
         }
+        icalcomponent_free(c);
     }
 
     icalset_free(s2);
