@@ -2,18 +2,19 @@
  FILE: stow.c
  CREATOR: eric 29 April 2000
 
- (C) COPYRIGHT 2000 Eric Busboom <eric@civicknowledge.com>
+ (C) COPYRIGHT 2000 Eric Busboom <eric@softwarestudio.org>
+      http://www.softwarestudio.org
 
  This library is free software; you can redistribute it and/or modify
  it under the terms of either:
 
     The LGPL as published by the Free Software Foundation, version
-    2.1, available at: https://www.gnu.org/licenses/lgpl-2.1.html
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
 
  Or:
 
     The Mozilla Public License Version 2.0. You may obtain a copy of
-    the License at https://www.mozilla.org/MPL/
+    the License at http://www.mozilla.org/MPL/
 
  The Initial Developer of the Original Code is Eric Busboom
 ======================================================================*/
@@ -33,7 +34,6 @@
 #endif
 
 #define TMPSIZE 2048
-#define TMPSIZE_SMALL 128
 #define SENDMAIL "/usr/lib/sendmail -t"
 
 char *program_name;
@@ -105,21 +105,7 @@ enum file_type test_file(char *path)
     return type;
 }
 
-static void byebye(int code, struct options_struct *opt)
-{
-    if (opt->output_file) {
-        free(opt->output_file);
-    }
-    if (opt->input_file) {
-        free(opt->input_file);
-    }
-    if (opt->calid) {
-        free(opt->calid);
-    }
-    exit(code);
-}
-
-static char *lowercase(const char *str)
+char *lowercase(const char *str)
 {
     char *new;
     char *p = 0;
@@ -170,8 +156,8 @@ char *make_mime(const char *to, const char *from, const char *subject,
 
     char mime_part_1[TMPSIZE];
     char mime_part_2[TMPSIZE];
-    char content_id[TMPSIZE_SMALL];
-    char boundary[TMPSIZE_SMALL];
+    char content_id[TMPSIZE];
+    char boundary[TMPSIZE];
     struct utsname uts;
     char *m;
 
@@ -183,8 +169,8 @@ char *make_mime(const char *to, const char *from, const char *subject,
     uname(&uts);
 
     srand((unsigned int)(time(0) << getpid()));
-    snprintf(content_id, TMPSIZE_SMALL, "%ld-%d@%s", (long)time(0), rand(), uts.nodename);
-    snprintf(boundary, TMPSIZE_SMALL, "%ld-%d-%s", (long)time(0), rand(), uts.nodename);
+    snprintf(content_id, TMPSIZE, "%d-%d@%s", (int)time(0), rand(), uts.nodename);
+    snprintf(boundary, TMPSIZE, "%d-%d-%s", (int)time(0), rand(), uts.nodename);
 //krazy:cond=style
     snprintf(mime_part_1, TMPSIZE, "Content-ID: %s\n\
 Content-type: text/plain\n\
@@ -250,7 +236,7 @@ void return_failure(icalcomponent *comp, char *message, struct options_struct *o
     if (p == 0) {
         fprintf(stderr,
                 "%s: fatal. Could not open pipe to sendmail (\"%s\") \n", program_name, SENDMAIL);
-        byebye(1, opt);
+        exit(1);
     }
 
     mime = make_mime(org_addr, local_attendee, "iMIP error",
@@ -298,8 +284,8 @@ icalcomponent *make_reply(icalcomponent *comp, icalproperty *return_status,
     reply =
         icalcomponent_vanew(
             ICAL_VCALENDAR_COMPONENT,
-            icalproperty_new_version("2.0"),
-            icalproperty_new_prodid(prodid),
+            icalproperty_new_version(strdup("2.0")),
+            icalproperty_new_prodid(strdup(prodid)),
             icalproperty_new_method(ICAL_METHOD_REPLY),
             icalcomponent_vanew(
                 ICAL_VEVENT_COMPONENT,
@@ -357,7 +343,7 @@ int check_attendee(icalproperty *p, struct options_struct *opt)
 }
 
 char static_component_error_str[MAXPATHLEN];
-char *check_component(icalcomponent *comp, icalproperty **return_status,
+char *check_component(icalcomponent *comp, icalproperty ** return_status,
                       struct options_struct *opt)
 {
     char *component_error_str = 0;
@@ -373,8 +359,8 @@ char *check_component(icalcomponent *comp, icalproperty **return_status,
 
     /*{
        icalrequeststatus code;
-       const char *desc;
-       const char *debug;
+       const char* desc;
+       const char* debug;
        }; */
 
     *return_status = 0;
@@ -517,24 +503,18 @@ void get_options(int argc, char *argv[], struct options_struct *opt)
         case 'i':{
                 /* Input comes from named file */
                 opt->input_source = INPUT_FROM_FILE;
-                if (opt->input_file) {
-                    free(opt->input_file);
-                }
                 opt->input_file = strdup(optarg);
                 break;
             }
         case 'o':{
                 /* Output goes to named file. Default */
-                if (opt->output_file) {
-                    free(opt->output_file);
-                }
                 opt->output_file = strdup(optarg);
                 opt->storage = STORE_IN_FILE;
                 break;
             }
         case 'd':{
                 /* Output goes to database */
-                fprintf(stderr, "%s: option -d is unimplemented\n", program_name);
+                fprintf(stderr, "%s: option -d is unimplmented\n", program_name);
                 opt->storage = STORE_IN_DB;
                 errflg++;
                 break;
@@ -547,7 +527,6 @@ void get_options(int argc, char *argv[], struct options_struct *opt)
                 /* Set the calid for the output database or
                    file. Default is user name of user running
                    program */
-                free(opt->calid);
                 opt->calid = strdup(optarg);
                 break;
             }
@@ -572,8 +551,9 @@ void get_options(int argc, char *argv[], struct options_struct *opt)
         }
 
         if (errflg > 0) {
-            byebye(1, opt);
-         }
+            usage("");
+            exit(1);
+        }
     }
 
     if (opt->calid == 0) {
@@ -598,10 +578,11 @@ void get_options(int argc, char *argv[], struct options_struct *opt)
             fprintf(stderr,
                     "%s: Can't get username. Try explicitly specifying the output file with -o",
                     program_name);
-            byebye(1, opt);
+            exit(1);
         }
 
         /* Find password entry for user */
+        /* cppcheck-suppress getpwentCalled as we don't care about multi-threaded in a test prog */
         while ((pw = getpwent()) != 0) {
             if (strcmp(user, pw->pw_name) == 0) {
                 break;
@@ -610,10 +591,10 @@ void get_options(int argc, char *argv[], struct options_struct *opt)
 
         if (pw == 0) {
             fprintf(stderr,
-                    "%s: Can't get password entry for user \"%s\" "
+                    "%s: Can't get get password entry for user \"%s\" "
                     "Try explicitly specifying the output file with -o",
                     program_name, user);
-            byebye(1, opt);
+            exit(1);
         }
 
         if (pw->pw_dir == 0) {
@@ -621,7 +602,7 @@ void get_options(int argc, char *argv[], struct options_struct *opt)
                     "%s: User \"%s\" has no home directory. "
                     "Try explicitly specifying the output file with -o",
                     program_name, user);
-            byebye(1, opt);
+            exit(1);
         }
 
         snprintf(file, MAXPATHLEN, "%s/.facs/%s", pw->pw_dir, opt->calid);
@@ -655,7 +636,7 @@ void get_options(int argc, char *argv[], struct options_struct *opt)
                             "%s: Failed to create calendar directory %s: %s\n",
                             program_name, facspath, strerror(errno));
                     free(facspath);
-                    byebye(1, opt);
+                    exit(1);
                 } else {
                     fprintf(stderr, "%s: Creating calendar directory %s\n", program_name, facspath);
                 }
@@ -664,7 +645,7 @@ void get_options(int argc, char *argv[], struct options_struct *opt)
                 fprintf(stderr, "%s: Cannot create calendar directory %s\n",
                         program_name, facspath);
                 free(facspath);
-                byebye(1, opt);
+                exit(1);
             }
         }
         free(facspath);
@@ -688,7 +669,7 @@ void store_component(icalcomponent *comp, struct options_struct *opt)
             fprintf(stderr,
                     "%s: Failed to get incoming component directory: %s\n",
                     program_name, icalerror_strerror(icalerrno));
-            byebye(1, opt);
+            exit(1);
         }
 
         error = icalfileset_add_component(fs, comp);
@@ -696,7 +677,7 @@ void store_component(icalcomponent *comp, struct options_struct *opt)
         if (error != ICAL_NO_ERROR) {
             fprintf(stderr, "%s: Failed to write incoming component: %s\n",
                     program_name, icalerror_strerror(icalerrno));
-            byebye(1, opt);
+            exit(1);
         }
 
         error = icalfileset_commit(fs);
@@ -704,7 +685,7 @@ void store_component(icalcomponent *comp, struct options_struct *opt)
         if (error != ICAL_NO_ERROR) {
             fprintf(stderr, "%s: Failed to commit incoming cluster: %s\n",
                     program_name, icalerror_strerror(icalerrno));
-            byebye(1, opt);
+            exit(1);
         }
 
         icalset_free(fs);
@@ -722,7 +703,7 @@ char *read_stream(char *s, size_t size, void *d)
     return c;
 }
 
-icalcomponent *read_nonmime_component(struct options_struct *opt)
+icalcomponent *read_nonmime_component(struct options_struct * opt)
 {
     FILE *stream;
     icalcomponent *comp;
@@ -735,7 +716,7 @@ icalcomponent *read_nonmime_component(struct options_struct *opt)
 
         if (stream == 0) {
             perror("Can't open input file");
-            byebye(1, opt);
+            exit(1);
         }
 
     } else {
@@ -787,7 +768,7 @@ icalcomponent *find_vcalendar(icalcomponent *comp)
     return 0;
 }
 
-icalcomponent *read_mime_component(struct options_struct *opt)
+icalcomponent *read_mime_component(struct options_struct * opt)
 {
     icalcomponent *comp, *mimecomp;
     FILE *stream;
@@ -797,7 +778,7 @@ icalcomponent *read_mime_component(struct options_struct *opt)
 
         if (stream == 0) {
             perror("Can't open input file");
-            byebye(1, opt);
+            exit(1);
         }
 
     } else {
@@ -818,7 +799,7 @@ icalcomponent *read_mime_component(struct options_struct *opt)
     return comp;
 }
 
-icalcomponent *read_component(struct options_struct *opt)
+icalcomponent *read_component(struct options_struct * opt)
 {
     if (opt->input_type == INPUT_IS_MIME) {
         return read_mime_component(opt);
@@ -826,9 +807,8 @@ icalcomponent *read_component(struct options_struct *opt)
         return read_nonmime_component(opt);
     } else {
         fprintf(stderr, "%s: Internal Error; unknown option for input_type\n", program_name);
-        byebye(1, opt);
+        exit(1);
     }
-    return (icalcomponent *)NULL;
 }
 
 int main(int argc, char *argv[])
@@ -845,7 +825,7 @@ int main(int argc, char *argv[])
 
     if ((options_error_str = check_options(&opt)) != 0) {
         usage(options_error_str);
-        byebye(1, &opt);
+        exit(1);
     }
 
     comp = read_component(&opt);
@@ -858,7 +838,7 @@ int main(int argc, char *argv[])
 
         return_failure(reply, component_error_str, &opt);
         icalcomponent_free(reply);
-        byebye(0, &opt);
+        exit(0);
     }
 
     store_component(comp, &opt);
@@ -866,7 +846,5 @@ int main(int argc, char *argv[])
     /* Don't free the component comp, since it is now part of the
        store, and will be freed there */
 
-    byebye(0, &opt);
-
-    return(0); //to avoid -Werror=return-type
+    exit(0);
 }
