@@ -5,15 +5,16 @@
  (C) COPYRIGHT 2000 Eric Busboom <eric@softwarestudio.org>
      http://www.softwarestudio.org
 
- The contents of this file are subject to the Mozilla Public License
- Version 1.0 (the "License"); you may not use this file except in
- compliance with the License. You may obtain a copy of the License at
- http://www.mozilla.org/MPL/
+ This library is free software; you can redistribute it and/or modify
+ it under the terms of either:
 
- Software distributed under the License is distributed on an "AS IS"
- basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
- the License for the specific language governing rights and
- limitations under the License.
+    The LGPL as published by the Free Software Foundation, version
+    2.1, available at: http://www.gnu.org/licenses/lgpl-2.1.html
+
+ Or:
+
+    The Mozilla Public License Version 2.0. You may obtain a copy of
+    the License at http://www.mozilla.org/MPL/
 
  The Original Code is eric. The Initial Developer of the Original
  Code is Eric Busboom
@@ -41,10 +42,10 @@ int main(int argc, char *argv[])
 {
     VObject *vcal = 0;
     icalcomponent *comp;
-    char *file;
+    const char *file;
 
     if (argc != 2) {
-        file = "../../test-data/user-cal.vcf";
+        file = TEST_DATADIR "/user-cal.vcf";
     } else {
         file = argv[1];
     }
@@ -57,5 +58,6 @@ int main(int argc, char *argv[])
 
     printf("%s\n", icalcomponent_as_ical_string(comp));
 
+    icalcomponent_free(comp);
     return 0;
 }
